@@ -43,6 +43,11 @@ typedef unsigned int uint32_t;
 #define MM_3DNOW   0x0008 //AMD 3DNOW 
 #define MM_SSE     0x0010 //SSE functions 
 #define MM_SSE2    0x0020 //PIV SSE2 functions 
+#define MM_3DNOWEXT 0x0040 //AMD 3DNow! ext.
+#define MM_SSE3    0x0080 //Prescot SSE3
+
+extern void * (*tc_memcpy)(void *, const void *, size_t);
+extern void tc_memcpy_init(int verbose, int mmflags);
 
 extern int mm_flags;
 int ac_mmflag();
@@ -50,9 +55,10 @@ void ac_mmtest();
 char *ac_mmstr(int flag, int mode);
 
 //ac_memcpy
-int ac_memcpy_mmx(char *dest, char *src, int bytes);
-int ac_memcpy_sse(char *dest, char *src, int bytes);
-int ac_memcpy_sse2(char *dest, char *src, int bytes);
+void * ac_memcpy_mmx(void *dest, const void *src, size_t bytes);
+void * ac_memcpy_sse(void *dest, const void *src, size_t bytes);
+void * ac_memcpy_sse2(void *dest, const void *src, size_t bytes);
+void * ac_memcpy_amdmmx(void *dest, const void *src, size_t bytes);
 
 //average (simple average over 2 rows)
 int ac_average_mmx(char *row1, char *row2, char *out, int bytes);
