@@ -10,8 +10,15 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
+#include <ctype.h>
+
 #include "config.h"
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
+
 #ifndef MAXPATH
 #define MAXPATH 260
 #endif
