@@ -26,16 +26,17 @@
 #include <unistd.h>
 
 #include "transcode.h"
+#include "probe_export.h"
 
 #define MOD_NAME    "export_ac3.so"
 #define MOD_VERSION "v0.1 (2003-02-26)"
 #define MOD_CODEC   "(video) null | (audio) ac3"
 
-#define MOD_PRE ac3
-#include "export_def.h"
-
 static int   verbose_flag=TC_QUIET;
 static int   capability_flag=TC_CAP_PCM;
+
+#define MOD_PRE ac3
+#include "export_def.h"
 static FILE *pFile = NULL;
 
 static inline int p_write (char *buf, size_t len)
@@ -64,18 +65,34 @@ static inline int p_write (char *buf, size_t len)
 MOD_open
 {
     int result;
+
+    /* check for ffmpeg */
+    if (tc_test_program("ffmpeg") != 0) return (TC_EXPORT_ERROR);
+
     if (param->flag == TC_AUDIO) {
 	char buf [PATH_MAX];
         char out_fname [PATH_MAX];
 
         strcpy(out_fname, vob->audio_out_file);
-        strcat(out_fname, ".ac3");
+
+	if(probe_export_attributes & TC_PROBE_NO_EXPORT_AEXT)
+	    strcat(out_fname, audio_ext);
+	else
+            strcat(out_fname, ".ac3");
 
 	if (vob->mp3bitrate == 0) {
-            fprintf (stderr, "[%s] Audio bitrate 0 is not valid, cannot cope.\n", MOD_NAME);
+            fprintf (stderr, "[%s] Please set the export audio bitrate\n", MOD_NAME);
             return(TC_EXPORT_ERROR);
         }
 
+	if (vob->mp3frequency == 0) {
+            fprintf (stderr, "[%s] Please set the export audio sample rate\n", MOD_NAME);
+            return(TC_EXPORT_ERROR);
+        }
+
+	fprintf(stderr, "[%s] *** This module is non-optimal ***\n", MOD_NAME);
+	fprintf(stderr, "[%s] *** Use -N 0x2000 instead of -y ...,ac3 (faster) ***\n", MOD_NAME);
+
         result = snprintf (buf, PATH_MAX,
                            "ffmpeg -y -f s%dle -ac %d -ar %d -i - -ab %d -acodec ac3 %s%s",
                            vob->dm_bits,
@@ -83,7 +100,7 @@ MOD_open
                            vob->mp3frequency,
                            vob->mp3bitrate,
                            out_fname,
-                           vob->verbose > 1 ? "" : " >&/dev/null");
+                           vob->verbose > 1 ? "" : " >/dev/null 2>&1");
 	if (result < 0) {
 	    perror("command buffer overflow");
 	    return(TC_EXPORT_ERROR); 
