@@ -41,7 +41,7 @@
 #  include <avifile/videoencoder.h>
 #  include <avifile/audioencoder.h>
 #  include <avifile/avm_fourcc.h>
-#  include <avifile/avm_creators.h>
+#  include <avifile/creators.h>
 #  include <avifile/image.h>
 #endif
 
