@@ -23,7 +23,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include "../libdvenc/dvenc.h"
+#include "libdvenc/dvenc.h"
 #include "transcode.h"
 #include "avilib.h"
 #include "aud_aux.h"
@@ -33,12 +33,12 @@
 #define MOD_VERSION "v0.5 (2003-07-24)"
 #define MOD_CODEC   "(video) Digital Video | (audio) MPEG/AC3/PCM"
 
-#define MOD_PRE dv
-#include "export_def.h"
-
 static int verbose_flag=TC_QUIET;
 static int capability_flag=TC_CAP_PCM|TC_CAP_RGB|TC_CAP_YUV|TC_CAP_AC3;
 
+#define MOD_PRE dv
+#include "export_def.h"
+
 static unsigned char *target; //[TC_FRAME_DV_PAL];
 
 static avi_t *avifile=NULL;
