@@ -23,23 +23,24 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include "../libdvenc/dvenc.h"
+#include "libdvenc/dvenc.h"
 #include "transcode.h"
 #include "vid_aux.h"
+#include "optstr.h"
 
 #define MOD_NAME    "export_dvraw.so"
 #define MOD_VERSION "v0.4 (2003-10-14)"
 #define MOD_CODEC   "(video) Digital Video | (audio) PCM"
 
+static int verbose_flag=TC_QUIET;
+static int capability_flag=TC_CAP_PCM|TC_CAP_RGB|TC_CAP_YUV|TC_CAP_VID|TC_CAP_YUV422;
+
 #define MOD_PRE dvraw
 #include "export_def.h"
 
 extern int _dv_raw_insert_audio(unsigned char * frame_buf, 
                      dv_enc_audio_info_t * audio, int isPAL);
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_PCM|TC_CAP_RGB|TC_CAP_YUV|TC_CAP_VID|TC_CAP_YUV422;
-
 static int fd;
 
 static int16_t *audio_bufs[4];
@@ -138,7 +139,7 @@ MOD_init
   if(param->flag == TC_VIDEO) {
     
     target = bufalloc(TC_FRAME_DV_PAL);
-    vbuf = bufalloc(SIZE_RGB_FRAME);
+    vbuf = bufalloc(PAL_W*PAL_H*3);
 
 #ifdef LIBDV_095
     if(vob->dv_yuy2_mode) {
@@ -242,6 +243,9 @@ MOD_open
     encoder->isPAL = (vob->ex_v_height==PAL_H);
     encoder->vlc_encode_passes = 3;
     encoder->static_qno = 0;
+    if (vob->ex_v_string != NULL)
+      if (optstr_get (vob->ex_v_string, "qno", "%d", &encoder->static_qno) == 1)
+        printf("[%s] using quantisation: %d\n", MOD_NAME, encoder->static_qno);
     encoder->force_dct = DV_DCT_AUTO;
 #else
     dvenc_set_parameter(format, vob->ex_v_height, vob->a_rate);
@@ -293,9 +297,9 @@ MOD_encode
   if(param->flag == TC_VIDEO) { 
     
     if(pass_through) {
-      memcpy(target, param->buffer, frame_size);
+      tc_memcpy(target, param->buffer, frame_size);
     } else { 
-      memcpy(vbuf, param->buffer, param->size);
+      tc_memcpy(vbuf, param->buffer, param->size);
     }
     
     if(verbose & TC_STATS) fprintf(stderr, "[%s] ---V---\n", MOD_NAME);
