@@ -39,15 +39,15 @@
 #define MOD_VERSION "v0.0.4 (2003-11-13)"
 #define MOD_CODEC   "(video) *"
 
-#define MOD_PRE im
-#include "export_def.h"
-
 static int verbose_flag=TC_QUIET;
 static int capability_flag=TC_CAP_YUV|TC_CAP_RGB|TC_CAP_PCM|TC_CAP_AUD;
 
+#define MOD_PRE im
+#include "export_def.h"
+
 static char buf2[PATH_MAX];
 
-static uint8_t tmp_buffer[SIZE_RGB_FRAME];
+static uint8_t *tmp_buffer; //[SIZE_RGB_FRAME];
 
 static int codec, width, height, row_bytes;
 
@@ -97,6 +97,9 @@ MOD_init
       if (quality <= 0) quality = 0;
 
       image_info->quality = quality;
+
+      if (!tmp_buffer) tmp_buffer = malloc (vob->ex_v_width*vob->ex_v_height*3);
+      if (!tmp_buffer) return 1;
        
       return(0);
     }
@@ -215,6 +218,10 @@ MOD_stop
     DestroyImageInfo(image_info);
     DestroyConstitute();
     DestroyMagick();
+
+    if (tmp_buffer) free(tmp_buffer);
+    tmp_buffer = NULL;
+
     return(0);
   }
 
