@@ -37,12 +37,12 @@
 #define MOD_VERSION "v0.2.1 (2003-08-06)"
 #define MOD_CODEC   "(video) *"
 
-#define MOD_PRE jpg
-#include "export_def.h"
-
 static int verbose_flag=TC_QUIET;
 static int capability_flag=TC_CAP_YUV|TC_CAP_RGB|TC_CAP_PCM|TC_CAP_AUD;
 
+#define MOD_PRE jpg
+#include "export_def.h"
+
 static char buf2[PATH_MAX];
 
 static int codec, width, height;
@@ -95,7 +95,7 @@ static void write_yuv_JPEG_file(char *filename, int quality,
   jpeg_set_defaults(&encinfo);
   encinfo.dct_method = JDCT_FASTEST;
 
-  jpeg_set_quality(&encinfo, JPEG_DEFAULT_QUALITY, TRUE);
+  jpeg_set_quality(&encinfo, quality, TRUE);
   encinfo.raw_data_in = TRUE;
   encinfo.in_color_space = JCS_YCbCr;
 
