@@ -33,37 +33,33 @@
 #include <unistd.h>
 #include <fcntl.h>
 
+#include <ffmpeg/avcodec.h>
+
+#include "transcode.h"
 #include "vid_aux.h"
 
 //-- experimental --
 //#define HAS_DNR    1
 //------------------
 
-#define HAS_FFMPEG 1
-
 #ifdef HAS_DNR
 #include "mpeg_dnr.c"
 #endif
 
-#include "transcode.h"
-#include "../bbmpeg/bbencode.h"
+#include "bbmpeg/bbencode.h"
 #include "probe_export.h"
 
-#ifdef HAS_FFMPEG
-#include "../ffmpeg/libavcodec/avcodec.h"
-#endif
-
 #ifdef HAS_DNR
 #define MOD_NAME    "export_mpeg_dnr.so"
 #else
 #define MOD_NAME    "export_mpeg.so"
 #endif
+
 #define MOD_VERSION "v1.2.3 (2003-08-21)"
-#ifdef HAS_FFMPEG
 #define MOD_CODEC   "(video) MPEG 1/2 | (audio) MPEG 1 Layer II"
-#else
-#define MOD_CODEC   "(video) MPEG 1/2"
-#endif
+
+static int verbose_flag=TC_QUIET;
+static int capability_flag=TC_CAP_PCM|TC_CAP_YUV|TC_CAP_RGB;
 
 #define MOD_PRE mpeg
 #include "export_def.h"
@@ -78,7 +74,6 @@ static int          bbmpeg_fnew   = 0;
 static int          bbmpeg_fcnt   = -1;
 static vob_t        bbmpeg_vob;
 
-#ifdef HAS_FFMPEG
 static AVCodec        *mpa_codec = NULL;
 static AVCodecContext mpa_ctx;
 static FILE*          mpa_out_file = NULL;
@@ -86,15 +81,6 @@ static char           *mpa_buf     = NULL;
 static int            mpa_buf_ptr  = 0;
 static int            mpa_bytes_ps, mpa_bytes_pf;
 static ReSampleContext *ReSamplectx=NULL;
-#endif
-
-static int verbose_flag=TC_QUIET;
-#ifdef HAS_FFMPEG
-static int capability_flag=TC_CAP_PCM|TC_CAP_YUV|TC_CAP_RGB;
-#else
-static int capability_flag=TC_CAP_YUV|TC_CAP_RGB;
-#endif
-
 
 //== cleanup/setup buffer to read source mpeg into ==
 //===================================================
@@ -183,7 +169,7 @@ MOD_open
     //-------------------------
     if (bbmpeg_fcnt<0) 
     {
-      memcpy(&bbmpeg_vob, vob, sizeof(vob_t));
+      tc_memcpy(&bbmpeg_vob, vob, sizeof(vob_t));
       bbmpeg_fcnt = 0;
     }
       
@@ -236,7 +222,6 @@ MOD_open
     return(0);
   }
   
-#ifdef HAS_FFMPEG  
   if(param->flag == TC_AUDIO) 
   {
     if (mpa_out_file == NULL)
@@ -295,7 +280,6 @@ MOD_open
     }
     return(0);
   }
-#endif
 
   // invalid flag
   return(TC_EXPORT_ERROR); 
@@ -321,6 +305,20 @@ MOD_init
     char *p2 = NULL;
     char *p3 = NULL;
 
+	fprintf(stderr, "%s", 
+			"\n"
+			"*** WARNING ***\n"
+			"*** You are using the \"mpeg\" export module. ***\n"
+			"*** This is probably not what you want. ***\n"
+			"*** This module is based on the bbmpeg library, ***\n"
+			"*** which is obsolete, as is this export module. ***\n"
+			"*** This module may be removed in a future ***\n"
+			"*** transcode release. ***\n"
+			"*** Use the mpeg2enc or ffmpeg export modules instead ***\n"
+			"*** in combination with a vcd, svcd or dvd export profile ***\n"
+			"*** WARNING ***\n"
+			"\n");
+
     //ThOe added RGB2YUV cap
     if(vob->im_v_codec == CODEC_RGB) {
 	if(tc_rgb2yuv_init(vob->ex_v_width, vob->ex_v_height)<0) {
@@ -519,7 +517,6 @@ MOD_init
     return(0);
   }
 
-#ifdef HAS_FFMPEG
   if(param->flag == TC_AUDIO) 
   {
     //fprintf(stderr, "[%s] *** init-a *** !\n", MOD_NAME); 
@@ -542,7 +539,6 @@ MOD_init
 	audio_ext = ".mpa";
     return(0);  
   }
-#endif
 
   // invalid flag
   return(TC_EXPORT_ERROR); 
@@ -597,14 +593,14 @@ MOD_encode
       }
       else
       {
-        memcpy(py_dst, py_src, size_l);
-        memcpy(pu_dst, pu_src, size_c);
-        memcpy(pv_dst, pv_src, size_c);
+        tc_memcpy(py_dst, py_src, size_l);
+        tc_memcpy(pu_dst, pu_src, size_c);
+        tc_memcpy(pv_dst, pv_src, size_c);
       }
 
 #ifdef HAS_DNR      
       dnr_run(my_fctx, py_dst);
-      if (my_fctx->undo) memcpy(py_dst, my_fctx->undo_data, my_fctx->img_size);
+      if (my_fctx->undo) tc_memcpy(py_dst, my_fctx->undo_data, my_fctx->img_size);
 #endif
 
       //-- return on incomplete buffer fill --
@@ -669,15 +665,14 @@ MOD_encode
         {
           bbmpeg_fcnt++;
           bbmpeg_fnew = 1;       // request new audio-file 
-          MOD_PRE_close(param);
-          MOD_PRE_open(param, &bbmpeg_vob);
+          RENAME(MOD_PRE, _close)(param);
+          RENAME(MOD_PRE, _open)(param, &bbmpeg_vob);
         }
       }
 
       return(0);
   }
 
-#ifdef HAS_FFMPEG  
   if(param->flag == TC_AUDIO) 
   {
     int  in_size, out_size, new_size;
@@ -689,8 +684,8 @@ MOD_encode
     if (bbmpeg_fnew)
     {
       bbmpeg_fnew = 0;
-      MOD_PRE_close(param);
-      MOD_PRE_open(param, &bbmpeg_vob);
+      RENAME(MOD_PRE, _close)(param);
+      RENAME(MOD_PRE, _open)(param, &bbmpeg_vob);
     }        
 
     //-- input buffer and amount of bytes -- 
@@ -720,7 +715,7 @@ MOD_encode
       //------------------------------
       if ( bytes_avail >= bytes_needed ) {
 	
-	memcpy(&mpa_buf[mpa_buf_ptr], in_buf, bytes_needed);
+	tc_memcpy(&mpa_buf[mpa_buf_ptr], in_buf, bytes_needed);
 	
 	out_size = avcodec_encode_audio(&mpa_ctx, (unsigned char *)out_buf, 
 					OUTBUF_SIZE, (short *)mpa_buf);
@@ -736,7 +731,7 @@ MOD_encode
       //--------------------------------------------------------------- 
       else {
 	
-	memcpy(&mpa_buf[mpa_buf_ptr], param->buffer, bytes_avail);
+	tc_memcpy(&mpa_buf[mpa_buf_ptr], param->buffer, bytes_avail);
         mpa_buf_ptr += bytes_avail;
         return (0);
       }
@@ -761,12 +756,11 @@ MOD_encode
     //--------------------------------------
     if (in_size > 0) {
       mpa_buf_ptr = in_size; 
-      memcpy(mpa_buf, in_buf, mpa_buf_ptr);
+      tc_memcpy(mpa_buf, in_buf, mpa_buf_ptr);
     }
     
     return(0);
   }
-#endif
   
   // invalid flag
   return(TC_EXPORT_ERROR); 
@@ -794,7 +788,6 @@ MOD_stop
     return(0);
   }
 
-#ifdef HAS_FFMPEG  
   if(param->flag == TC_AUDIO) 
   {
     //-- cleanup encoder --
@@ -802,7 +795,6 @@ MOD_stop
     
     return (0);
   }  
-#endif
   
   return(TC_EXPORT_ERROR);     
 }
@@ -816,7 +808,6 @@ MOD_stop
 MOD_close
 {  
 
-#ifdef HAS_FFMPEG
   if(param->flag == TC_AUDIO) 
   {
     //-- release encoder --
@@ -836,7 +827,6 @@ MOD_close
     
     return (0);
   } 
-#endif
     
   if(param->flag == TC_VIDEO) 
   {
