@@ -30,11 +30,11 @@
 #define MOD_VERSION "v0.0.5 (2003-08-31)"
 #define MOD_CODEC   "(video) null | (audio) ogg"
 
-#define MOD_PRE ogg
-#include "export_def.h"
-
 static int   verbose_flag=TC_QUIET;
 static int   capability_flag=TC_CAP_PCM;
+
+#define MOD_PRE ogg
+#include "export_def.h"
 static FILE *pFile = NULL;
 
 static inline int p_write (char *buf, size_t len)
@@ -65,6 +65,9 @@ MOD_open
     int result;
     int ifreq,ofreq;
 
+    /* check for oggenc */
+    if (tc_test_program("oggenc") != 0) return (TC_EXPORT_ERROR);
+        
     ofreq = vob->mp3frequency;
     ifreq = vob->a_rate;
 
