@@ -32,10 +32,13 @@
 #define MOD_VERSION "v0.1.8 (2003-08-23)"
 #define MOD_CODEC   "(video) YUV4MPEG2 | (audio) MPEG/AC3/PCM"
 
+static int verbose_flag=TC_QUIET;
+static int capability_flag=TC_CAP_YUV|TC_CAP_PCM|TC_CAP_AC3|TC_CAP_AUD|TC_CAP_RGB;
+
 #define MOD_PRE yuv4mpeg
 #include "export_def.h"
 
-#if defined(HAVE_MJPEG_INC)
+#if defined(HAVE_MJPEGTOOLS_INC)
 #include "yuv4mpeg.h"
 #include "mpegconsts.h"
 #else
@@ -43,9 +46,6 @@
 #include "mjpegtools/mpegconsts.h"
 #endif
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_YUV|TC_CAP_PCM|TC_CAP_AC3|TC_CAP_AUD|TC_CAP_RGB;
-
 #ifndef DAR_4_3
 # define DAR_4_3      {   4, 3   }
 # define DAR_16_9     {  16, 9   }
@@ -139,7 +139,12 @@ MOD_open
 
     //note: this is the real framerate of the raw stream
     framerate = (vob->ex_frc==0) ? mpeg_conform_framerate(vob->ex_fps):mpeg_framerate(vob->ex_frc);
+    if (framerate.n==0 && framerate.d==0) {
+	framerate.n=vob->ex_fps*1000;
+	framerate.d=1000;
+    }
 
+    //printf("OUT %d %f %d %d\n", vob->ex_frc, vob->ex_fps, framerate.n, framerate.d);
     asr = (vob->ex_asr<0) ? vob->im_asr:vob->ex_asr;
     asrcode2asrratio(asr, &asr_rate);
 
@@ -151,8 +156,8 @@ MOD_open
     snprintf( dar_tag, 19, "XM2AR%03d", asr );
     y4m_xtag_add( y4m_si_xtags(&y4mstream), dar_tag );
     */
-    y4mstream.height = vob->ex_v_height;
-    y4mstream.width = vob->ex_v_width;
+    y4m_si_set_height(&y4mstream,vob->ex_v_height);
+    y4m_si_set_width(&y4mstream,vob->ex_v_width);
     
     size = vob->ex_v_width * vob->ex_v_height * 3/2;
     
@@ -198,13 +203,23 @@ MOD_encode
 	}
 	
 	
+#ifdef USE_NEW_MJPEGTOOLS_CODE
 	y4m_init_frame_info(&info);
 	
-	if(y4m_write_frame_header( fd, &info ) != Y4M_OK )
+	if(y4m_write_frame_header( fd, &y4mstream, &info ) != Y4M_OK )
 	{
 	    perror("write frame header");
 	    return(TC_EXPORT_ERROR);
 	}     
+#else
+	y4m_init_frame_info(&info);
+	
+	if(y4m_write_frame_header( fd, &info) != Y4M_OK )
+	{
+	    perror("write frame header");
+	    return(TC_EXPORT_ERROR);
+	}     
+#endif
 	
 	//do not trust param->size
 	if(p_write(fd, param->buffer, size) != size) {    
