@@ -104,7 +104,8 @@ int tc_filter(vframe_list_t *ptr, char *options)
   // transcodes internal video/audo frame processing routines
   // or after and determines video/audio context
   
-  if((ptr->tag & TC_PRE_PROCESS) && (ptr->tag & TC_VIDEO) && (vob->im_v_codec==CODEC_YUV))  {
+  if((ptr->tag & TC_PRE_PROCESS) && (ptr->tag & TC_VIDEO) && (vob->im_v_codec==CODEC_YUV) &&
+     !(ptr->attributes & TC_FRAME_IS_SKIPPED))  {
     
     deinterlace_bob_yuv_mmx(ptr->video_buf, ptr->video_buf, 
 			    ptr->v_width, ptr->v_height); 
