@@ -141,7 +141,7 @@ static inline void copy_field(char *to, char *from, int width, int height) {
 
   height >>= 1;
   while (height--) {
-    memcpy(to, from, width);
+    tc_memcpy(to, from, width);
     to += increment;
     from += increment;
   }
@@ -155,9 +155,9 @@ static inline void swap_fields(char *f1, char *f2, int width, int height) {
 
   height >>= 1;
   while (height--) {
-    memcpy(buffer, f1, width);
-    memcpy(f1, f2, width);
-    memcpy(f2, buffer, width);
+    tc_memcpy(buffer, f1, width);
+    tc_memcpy(f1, f2, width);
+    tc_memcpy(f2, buffer, width);
     f1 += increment;
     f2 += increment;
   }
