@@ -50,7 +50,7 @@
 #include "transcode.h"
 #include "framebuffer.h"
 #include "optstr.h"
-#include "../export/vid_aux.h"
+#include "export/vid_aux.h"
 
 static vob_t *vob=NULL;
 
@@ -310,7 +310,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	int x, y, max;
 	int strength = mfd->strength, invstrength = 255 - strength;
 	int threshold = mfd->threshold;
-	const int	srcpitch = ptr->v_width*sizeof(Pixel32);
+	// const int	srcpitch = ptr->v_width*sizeof(Pixel32);
 	const int	dstpitch = ptr->v_width*sizeof(Pixel32);
 
 	if (vob->im_v_codec == CODEC_YUV) {
@@ -357,8 +357,8 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	/* Fix up blur frame borders. */
 	srcp = src;
 	blurp = mfd->blur;
-	memcpy(blurp, srcp, bwidth);
-	memcpy(blurp + (height-1)*bwidth, srcp + (height-1)*pitch, bwidth);
+	tc_memcpy(blurp, srcp, bwidth);
+	tc_memcpy(blurp + (height-1)*bwidth, srcp + (height-1)*pitch, bwidth);
 	for (y = 0; y < height; y++)
 	{
 		*((unsigned int *)(&blurp[0])) = *((unsigned int *)(&srcp[0]));
@@ -489,8 +489,8 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	/* Fix up output frame borders. */
 	srcp = src;
 	dstp = dst;
-	memcpy(dstp, srcp, bwidth);
-	memcpy(dstp + (height-1)*pitch, srcp + (height-1)*pitch, bwidth);
+	tc_memcpy(dstp, srcp, bwidth);
+	tc_memcpy(dstp + (height-1)*pitch, srcp + (height-1)*pitch, bwidth);
 	for (y = 0; y < height; y++)
 	{
 		*((unsigned int *)(&dstp[0])) = *((unsigned int *)(&srcp[0]));
