@@ -56,7 +56,7 @@
 #include "transcode.h"
 #include "framebuffer.h"
 #include "optstr.h"
-#include "../export/vid_aux.h"
+#include "export/vid_aux.h"
 
 static vob_t *vob=NULL;
 
@@ -455,7 +455,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 					dst1 = dst_buf;
 					for (y = 0; y < h; y++)
 					{
-						memcpy(dst1, src1, wtimes4);
+						tc_memcpy(dst1, src1, wtimes4);
 						src1 = (Pixel *)((char *)src1 + srcpitch);
 						dst1 = (Pixel *)((char *)dst1 + dstpitch);
 					}
@@ -473,7 +473,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 				saved = mfd->saveFrame + w;
 				for (y = 0; y < hover2; y++)
 				{					
-					memcpy(saved, src1, wtimes4);
+					tc_memcpy(saved, src1, wtimes4);
 					src1 = (Pixel *)((char *)src1 + srcpitchtimes2);
 					saved += wtimes2;
 				}
@@ -481,7 +481,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 				dst1 = (Pixel32 *)((char *)dst_buf+ dstpitch);
 				for (y = 0; y < hover2; y++)
 				{					
-					memcpy(dst1, src1, wtimes4);
+					tc_memcpy(dst1, src1, wtimes4);
 					src1 = (Pixel *)((char *)src1 + srcpitchtimes2);
 					dst1 = (Pixel *)((char *)dst1 + dstpitchtimes2);
 				}
@@ -489,7 +489,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 				saved = mfd->saveFrame + w;
 				for (y = 0; y < hover2; y++)
 				{					
-					memcpy(dst1, saved, wtimes4);
+					tc_memcpy(dst1, saved, wtimes4);
 					dst1 = (Pixel *)((char *)dst1 + dstpitchtimes2);
 					saved += wtimes2;
 				}
@@ -538,7 +538,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 			d1 = dst1;
 			for (y = 0; y < hover2; y++)
 			{
-				memcpy(d1, s1, wtimes4);
+				tc_memcpy(d1, s1, wtimes4);
 				s1 = (Pixel *)((char *)s1 + srcpitchtimes2);
 				d1 = (Pixel *)((char *)d1 + dstpitchtimes2);
 			}
@@ -553,7 +553,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 				d2 = dst2;
 				for (y = 0; y < hover2; y++)
 				{
-					memcpy(d2, s1, wtimes4);
+					tc_memcpy(d2, s1, wtimes4);
 					s1 = (Pixel *)((char *)s1 + srcpitchtimes2);
 					d2 = (Pixel *)((char *)d2 + dstpitchtimes2);
 				}
@@ -564,7 +564,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 				sv = saved;
 				for (y = 0; y < hover2; y++)
 				{
-					memcpy(d2, sv, wtimes4);
+					tc_memcpy(d2, sv, wtimes4);
 					sv += wtimes2;
 					d2 = (Pixel *)((char *)d2 + dstpitchtimes2);
 				}
@@ -575,7 +575,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 			sv = saved;
 			for (y = 0; y < hover2; y++)
 			{
-				memcpy(sv, s2, wtimes4);
+				tc_memcpy(sv, s2, wtimes4);
 				sv += wtimes2;
 				s2 = (Pixel *)((char *)s2 + srcpitchtimes2);
 			}
@@ -590,7 +590,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 			dst1 = src_buf;
 			for (y = 0; y < h; y++)
 			{
-				memcpy(dst1, src1, wtimes4);
+				tc_memcpy(dst1, src1, wtimes4);
 				src1 = (Pixel *)((char *)src1 + srcpitch);
 				dst1 = (Pixel *)((char *)dst1 + dstpitch);
 			}
@@ -604,7 +604,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 		dst1 = dst_buf;
 		for (y = 0; y < h; y++)
 		{
-			memcpy(dst1, src1, srcpitch);
+			tc_memcpy(dst1, src1, srcpitch);
 			src1 = (Pixel *)((char *)src1 + srcpitch);
 			dst1 = (Pixel *)((char *)dst1 + dstpitch);
 		}
@@ -948,7 +948,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
     // The first line gets a free ride.
 	src = src_buf;
 	dst = dst_buf;
-	memcpy(dst, src, wtimes4);
+	tc_memcpy(dst, src, wtimes4);
 	src = (Pixel *)((char *)src_buf + srcpitch);
 	srcminus = (Pixel *)((char *)src - srcpitch);
 	srcplus = (Pixel *)((char *)src + srcpitch);
@@ -1113,7 +1113,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 				else
 				{
 					// Even line; pass it through.
-					memcpy(dst, src, wtimes4);
+					tc_memcpy(dst, src, wtimes4);
 				}
 			}
 		}
@@ -1132,7 +1132,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	}
 	
 	// The last line gets a free ride.
-	memcpy(dst, src, wtimes4);
+	tc_memcpy(dst, src, wtimes4);
 
 filter_done:
 	convert_argb2rgb (mfd->convertFrameOut, ptr->video_buf, ptr->v_width, ptr->v_height);
