@@ -104,12 +104,14 @@ count: 1-256
 stride: -32000 - 320000
 */
 
+#if 0 // unused, EMS
 static unsigned int get_prefetch_const (int blocksize_in_vectors, int block_count, int block_stride) 
 {
     return ((blocksize_in_vectors<<24)&0x1F000000) | 
 	   ((block_count<<16)&0x00FF0000)          |
 	    (block_stride&0xFFFF);
 }
+#endif
 
 static unsigned char *bufalloc(size_t size, char *location)
 {
@@ -241,7 +243,7 @@ static void Erode_Dilate (uint8_t *_moving, uint8_t *_fmoving, int width, int he
 	    {
 		uint8_t  res[8];
 
-		memcpy(fmoving, moving, 4);
+		tc_memcpy(fmoving, moving, 4);
 
 		m = p;
 
@@ -405,7 +407,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	int			cubic = mfd->cubic;
 	static int 		counter=0;
 	const int		can_use_mmx = !(w%8); // width must a multiple of 8
-	const int		can_use_altivec = !(w%16); // width must a multiple of 16
+	// const int		can_use_altivec = !(w%16); // width must a multiple of 16
 
 
 	char * dst_buf;
@@ -476,7 +478,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 			    // write to moving
 			    movd_r2m(mm0, *moving);
 
-			    memcpy(prev, src, 4);
+			    tc_memcpy(prev, src, 4);
 
 			    src+=4;
 			    prev+=4;
@@ -645,7 +647,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 				// write to moving
 				movd_r2m(mm0, *moving);
 
-				memcpy(prev, src, 4);
+				tc_memcpy(prev, src, 4);
 
 				src+=4;
 				prev+=4;
@@ -706,7 +708,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 				// write to moving
 				movd_r2m(mm0, *moving);
 
-				memcpy(prev, src, 4);
+				tc_memcpy(prev, src, 4);
 
 				src+=4;
 				prev+=4;
@@ -993,7 +995,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	src = src_buf;
 	dst = dst_buf;
 
-	memcpy(dst, src, w);
+	tc_memcpy(dst, src, w);
 	src = src_buf + srcpitch;
 	srcminus = src - srcpitch;
 	srcplus = src + srcpitch;
@@ -1080,7 +1082,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 		movingplus += (w+PAD);
 	    }
 	    // The last line gets a free ride.
-	    memcpy(dst, src, w);
+	    tc_memcpy(dst, src, w);
 
 	    if (clamp_f == clamp_Y)
 		counter++;
@@ -1209,10 +1211,12 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 		movingminus += (w+PAD);
 		movingplus += (w+PAD);
 	    }
-	}
-	emms();
 
-	return;
+	    emms();
+	    return;
+	}
+
+	emms();
 
 	// Doing line interpolate. Thus, even lines are going through
 	// for moving and non-moving mode. Odd line pixels will be subject
@@ -1244,7 +1248,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	    else
 	    {
 		// Even line; pass it through.
-		memcpy(dst, src, w);
+		tc_memcpy(dst, src, w);
 	    }
 	    src +=  srcpitch;
 	    srcminus += srcpitch;
@@ -1263,7 +1267,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	}
 
 	// The last line gets a free ride.
-	memcpy(dst, src, w);
+	tc_memcpy(dst, src, w);
 	if (clamp_f == clamp_Y)
 	    counter++;
 
@@ -1554,7 +1558,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 			  mfd->movingV+off, mfd->fmovingV+off, clamp_UV, mfd->chromathres);
 	  } else {
 	      //pass through
-	      memcpy(mfd->buf+U, ptr->video_buf+U, ptr->v_width*ptr->v_height/2);
+	      tc_memcpy(mfd->buf+U, ptr->video_buf+U, ptr->v_width*ptr->v_height/2);
 	      //memset(mfd->buf+U, BLACK_BYTE_UV, ptr->v_width*ptr->v_height/2);
 	  }
 
@@ -1563,7 +1567,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	  memset(mfd->buf+U, BLACK_BYTE_UV, ptr->v_width*ptr->v_height/2);
 			  */
 
-	  memcpy (ptr->video_buf, mfd->buf, ptr->video_size);
+	  tc_memcpy (ptr->video_buf, mfd->buf, ptr->video_size);
 
 	  return 0;
   }
