@@ -22,7 +22,7 @@
  */
 
 #define MOD_NAME    "filter_text.so"
-#define MOD_VERSION "v0.1.3 (2003-10-16)"
+#define MOD_VERSION "v0.1.4 (2004-02-14)"
 #define MOD_CAP     "write text in the image"
 #define MOD_AUTHOR  "Tilmann Bitterberg"
 
@@ -52,6 +52,7 @@
 #include "transcode.h"
 #include "framebuffer.h"
 #include "optstr.h"
+#include "video_trans.h"
 
 // basic parameter
 
@@ -96,6 +97,7 @@ typedef struct MyFilterData {
 	int antialias;       /* do sub frame anti-aliasing (not done) */
 	int R, G, B;         /* color to apply in RGB */
 	int Y, U, V;         /* color to apply in YUV */
+	int flip;
 
     /* private */
 	int opaque;          /* Opaqueness of the text */
@@ -151,6 +153,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
   static char *buf = NULL;
   char *p, *q;
   char *default_font = "/usr/X11R6/lib/X11/fonts/TrueType/arial.ttf";
+  extern int flip; // transcode.c
   
   if (ptr->tag & TC_AUDIO)
       return 0;
@@ -235,6 +238,10 @@ int tc_filter(vframe_list_t *ptr, char *options)
     mfd->top_space = 0;
     mfd->boundX=0;
     mfd->boundY=0;
+    mfd->flip = flip;
+
+    //if the user wants flipping, do it here in this filter
+    if (mfd->flip) flip=TC_FALSE;
 
     mfd->R = mfd->B = mfd->G = 0xff; // white
     mfd->Y = 240; mfd->U = mfd->V = 128;
@@ -417,8 +424,8 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	return (-1);
     }
 
-    //render into temp buffer
 
+    //render into temp buffer
     if (codec == CODEC_YUV) {
 
 	p = buf+mfd->posy*width+mfd->posx;
@@ -586,7 +593,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	    p = ptr->video_buf + 3*(height-mfd->posy)*width + 3*mfd->posx;
 	    q =            buf + 3*(height-mfd->posy)*width + 3*mfd->posx;
 
-	    //memcpy(ptr->video_buf, buf, 3*width*height);
+	    //tc_memcpy(ptr->video_buf, buf, 3*width*height);
 
 	    for (h=0; h>-mfd->boundY; h--) {
 		for (w=0; w<mfd->boundX; w++)  {
@@ -606,7 +613,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 			}
 
 			// write to image
-			p[3*((h)*width+w)-(2-i)] =  e&0xff;
+			p[3*(h*width+w)-(2-i)] =  e&0xff;
 		    }
 		}
 	    }
@@ -623,6 +630,23 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	    if (mfd->opaque>MAX_OPACITY) mfd->opaque=MAX_OPACITY;
 	}
 
+	if (mfd->flip) {
+	    switch (codec) {
+		case CODEC_RGB:
+		    rgb_flip(ptr->video_buf, ptr->v_width, ptr->v_height);
+		    break;
+		case CODEC_YUV:
+		    yuv_flip(ptr->video_buf, ptr->v_width, ptr->v_height);
+		    break;
+		case CODEC_YUV422:
+		    yuv422_flip(ptr->video_buf, ptr->v_width, ptr->v_height);
+		    break;
+		default:
+		    printf("unsupported\n");
+		    break;
+	    }
+	}
+
 
     }
   }
