@@ -47,7 +47,7 @@
 #include "framebuffer.h"
 #include "optstr.h"
 #include "filter.h"
-#include "../src/video_trans.h"
+#include "src/video_trans.h"
 
 // basic parameter
 unsigned char gamma_table[256];
@@ -73,10 +73,12 @@ static MyFilterData *mfd = NULL;
  *
  *-------------------------------------------------*/
 
+#if 0 // unused, EMS
 static void help_optstr(void) 
 {
    printf ("[%s] (%s) help\n", MOD_NAME, MOD_CAP);
 }
+#endif
 
 int tc_filter(vframe_list_t *ptr, char *options)
 {
@@ -250,7 +252,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
        init_aa_table(vob->aa_weight, vob->aa_bias);
 
        //UV components unchanged
-       memcpy(ptr->video_buf_Y[ptr->free]+ptr->v_width*ptr->v_height, 
+       tc_memcpy(ptr->video_buf_Y[ptr->free]+ptr->v_width*ptr->v_height, 
 	      ptr->video_buf + ptr->v_width*ptr->v_height, 
 	      ptr->v_width*ptr->v_height/2);
     
