@@ -29,7 +29,7 @@
 #include <dlfcn.h>
 #else
 # ifdef SYSTEM_DARWIN
-#  include "../libdldarwin/dlfcn.h"
+#  include "libdldarwin/dlfcn.h"
 # endif
 #endif
 
@@ -50,6 +50,16 @@
 #include "filter.h"
 #include "video_trans.h"
 
+/* -------------------------------------------------
+ *
+ * mandatory include files
+ *
+ *-------------------------------------------------*/
+
+#include "transcode.h"
+#include "framebuffer.h"
+
+
 static int cache_num=0;
 static int cache_ptr=0;
 static int cache_enabled=0;
@@ -66,19 +76,6 @@ static int w, h;
 static int cols=20;
 static int rows=20;
 
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include "transcode.h"
-#include "framebuffer.h"
-
 static char buffer[128];
 static int size=0;
 static int use_secondary_buffer=0;
@@ -174,6 +171,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
       optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VY4O", "1");
       optstr_param (options, "cache", "Number of raw frames to cache for seeking",  "%d", "15", "15", "255");
       optstr_param (options, "skip", "display only every Nth frame",  "%d", "0", "0", "255");
+      optstr_param (options, "fullscreen", "Display in fullscreen mode","", "0");
   }
 
   //----------------------------------
@@ -216,6 +214,14 @@ int tc_filter(vframe_list_t *ptr, char *options)
     if(xv_player != NULL) return(-1);
     if(!(xv_player = xv_player_new())) return(-1);
 
+
+    if (options != NULL) {
+      if(optstr_get (options, "fullscreen", "") == 0)
+        xv_player->display->full_screen = 1;
+    }
+
+
+
     //init filter
     
     w = tc_x_preview;
@@ -319,7 +325,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
   
   if( (ptr->tag & TC_PRE_PROCESS) && vid && cache_enabled) {
       process_ctr_cur = (process_ctr_cur+1)%3;
-      memcpy (process_buffer[process_ctr_cur], ptr->video_buf, ptr->video_size);
+      tc_memcpy (process_buffer[process_ctr_cur], ptr->video_buf, ptr->video_size);
       return 0;
   }
   if(pre && vid) {
@@ -329,7 +335,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
     if(!xv_player->display->dontdraw) {
       
       //0.6.2 (secondaray buffer for pass-through mode)
-      (use_secondary_buffer) ? memcpy(xv_player->display->pixels[0], (char*) ptr->video_buf2, size) : memcpy(xv_player->display->pixels[0], (char*) ptr->video_buf, size); 
+      (use_secondary_buffer) ? tc_memcpy(xv_player->display->pixels[0], (char*) ptr->video_buf2, size) : tc_memcpy(xv_player->display->pixels[0], (char*) ptr->video_buf, size); 
       
       //display video frame
       xv_display_show(xv_player->display);
@@ -383,7 +389,7 @@ void preview_cache_submit(char *buf, int id, int flag) {
 
   cache_ptr = (cache_ptr+1)%cache_num;
   
-  memcpy((char*) vid_buf[cache_ptr], buf, size);
+  tc_memcpy((char*) vid_buf[cache_ptr], buf, size);
   
   (flag & TC_FRAME_IS_KEYFRAME) ? sprintf(string, "%u *", id):sprintf(string, "%u", id);
   
@@ -411,15 +417,15 @@ int preview_filter_buffer(int frames_needed)
 
 #undef NO_PROCESS
 #ifdef NO_PROCESS
-	memcpy (run_buffer[0], (char *)vid_buf[cache_ptr-(current-1)], size);
-	memcpy (run_buffer[1], (char *)vid_buf[cache_ptr-(current-1)], size);
+	tc_memcpy (run_buffer[0], (char *)vid_buf[cache_ptr-(current-1)], size);
+	tc_memcpy (run_buffer[1], (char *)vid_buf[cache_ptr-(current-1)], size);
 #else
-	memcpy (run_buffer[0], process_buffer[(process_ctr_cur+1)%3], SIZE_RGB_FRAME);
-	memcpy (run_buffer[1], process_buffer[(process_ctr_cur+1)%3], SIZE_RGB_FRAME);
+	tc_memcpy (run_buffer[0], process_buffer[(process_ctr_cur+1)%3], SIZE_RGB_FRAME);
+	tc_memcpy (run_buffer[1], process_buffer[(process_ctr_cur+1)%3], SIZE_RGB_FRAME);
 #endif
 
 	if (i == 1) {
-	    memcpy (undo_buffer, (char *)vid_buf[cache_ptr], size);
+	    tc_memcpy (undo_buffer, (char *)vid_buf[cache_ptr], size);
 	}
 
 	ptr->bufid = 1;
@@ -481,10 +487,10 @@ int preview_filter_buffer(int frames_needed)
 
 	plugin_enable_id (this_filter);
 	
-	memcpy (vid_buf[cache_ptr-current+1], ptr->video_buf, size);
+	tc_memcpy (vid_buf[cache_ptr-current+1], ptr->video_buf, size);
 	preview_cache_draw(0);
 
-	memcpy ((char *)vid_buf[cache_ptr], undo_buffer, size);
+	tc_memcpy ((char *)vid_buf[cache_ptr], undo_buffer, size);
     }
     return 0;
 }
@@ -604,10 +610,10 @@ redisplay_frame:
 	vframe_list_t ptr;
 
 	if (!disable)
-	    memcpy (undo_buffer, (char *)vid_buf[cache_ptr], size);
+	    tc_memcpy (undo_buffer, (char *)vid_buf[cache_ptr], size);
 
-	memcpy (run_buffer[0], (char *)vid_buf[cache_ptr-(current-1)], size);
-	memcpy (run_buffer[1], (char *)vid_buf[cache_ptr-(current-1)], size);
+	tc_memcpy (run_buffer[0], (char *)vid_buf[cache_ptr-(current-1)], size);
+	tc_memcpy (run_buffer[1], (char *)vid_buf[cache_ptr-(current-1)], size);
 
 	ptr.bufid = 1;
 	ptr.next = &ptr;
@@ -654,7 +660,7 @@ redisplay_frame:
 	process_vid_plugins (&ptr);
 	plugin_enable_id (this_filter);
 	
-	memcpy (vid_buf[cache_ptr-current+1], ptr.video_buf, size);
+	tc_memcpy (vid_buf[cache_ptr-current+1], ptr.video_buf, size);
 	preview_cache_draw(0);
     }
     return;
@@ -666,7 +672,7 @@ void preview_cache_undo(void)
 {
     if (!cache_enabled) return;
 
-    memcpy((char *)vid_buf[cache_ptr], undo_buffer, size);
+    tc_memcpy((char *)vid_buf[cache_ptr], undo_buffer, size);
     preview_cache_draw(0);
 }
 void preview_cache_draw(int next) {
@@ -681,7 +687,7 @@ void preview_cache_draw(int next) {
   
   cache_ptr%=cache_num;
 
-  memcpy(xv_player->display->pixels[0], (char*) vid_buf[cache_ptr], size);
+  tc_memcpy(xv_player->display->pixels[0], (char*) vid_buf[cache_ptr], size);
 
   //display video frame
   xv_display_show(xv_player->display);
@@ -820,7 +826,7 @@ char **char2bmp(char c) {
 
 int preview_grab_jpeg(void) 
 {
-#if defined(__FreeBSD__) || defined (__APPLE__)
+#ifdef SYS_BSD
     const
 #endif  
     char *error;
@@ -853,7 +859,7 @@ int preview_grab_jpeg(void)
 	ret = JPEG_export(TC_EXPORT_NAME, &export_para, NULL);
 
 	mvob = malloc(sizeof(vob_t));
-	memcpy (mvob, vob, sizeof(vob_t));
+	tc_memcpy (mvob, vob, sizeof(vob_t));
 	mvob->video_out_file = prefix;
 
 	export_para.flag = TC_VIDEO;
