@@ -33,13 +33,17 @@
 #include <string.h>
 
 #include "pv.h"
-#include "../../src/socket.h"
+#include "src/socket.h"
 
 #include <sys/ipc.h>
 #include <sys/shm.h>
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 // FIXME: Use autoconf for this!!
-#if defined(__FreeBSD__) || defined(__APPLE__) /* We don't have on_exit() */
+#ifdef SYS_BSD /* We don't have on_exit() */
 xv_display_t 	*xv_dpy_on_exit_hack = NULL;
 #endif
 
@@ -127,7 +131,7 @@ void xv_display_exit(xv_display_t *dv_dpy) {
   
   free(dv_dpy);
   dv_dpy = NULL;
-#if defined(__FreeBSD__) || defined(__APPLE__) /* We don't have on_exit() */
+#ifdef SYS_BSD /* We don't have on_exit() */
   xv_dpy_on_exit_hack = NULL;
 #endif
 } // xv_display_exit
@@ -583,6 +587,13 @@ static int xv_display_Xv_init(xv_display_t *dv_dpy, char *w_name, char *i_name,
   }
 
   if (!(flags & XV_NOSAWINDOW)) {
+
+    if(dv_dpy->full_screen) {
+      int  screen = XDefaultScreen(dv_dpy->dpy);
+      dv_dpy->lwidth = dv_dpy->dwidth =DisplayWidth(dv_dpy->dpy, screen); 
+      dv_dpy->lheight = dv_dpy->dheight = DisplayHeight(dv_dpy->dpy, screen);
+    }
+
     dv_dpy->win = XCreateSimpleWindow(dv_dpy->dpy,
 				       dv_dpy->rwin,
 				       0, 0,
@@ -590,6 +601,18 @@ static int xv_display_Xv_init(xv_display_t *dv_dpy, char *w_name, char *i_name,
 				       0,
 				       XWhitePixel(dv_dpy->dpy, scn_id),
 				       XBlackPixel(dv_dpy->dpy, scn_id));
+
+    if(dv_dpy->full_screen) {
+      static Atom           XA_WIN_STATE = None;
+      long                  propvalue[2];
+
+      XA_WIN_STATE = XInternAtom (dv_dpy->dpy, "_NET_WM_STATE", False);
+      propvalue[0] = XInternAtom (dv_dpy->dpy, "_NET_WM_STATE_FULLSCREEN", False);
+      propvalue[1] = 0;
+                
+      XChangeProperty (dv_dpy->dpy, dv_dpy->win, XA_WIN_STATE, XA_ATOM, 
+                       32, PropModeReplace, (unsigned char *)propvalue, 1);
+    }
   } else {
   }
 
@@ -635,14 +658,13 @@ static int xv_display_Xv_init(xv_display_t *dv_dpy, char *w_name, char *i_name,
   return 1;
 } // xv_display_Xv_init 
 
-
-
+#if 0  // unused
+#ifndef SYS_BSD /* We don't have on_exit() */
 static void xv_display_exit_handler(int code, void *arg)
 {
   if(code && arg) xv_display_exit(arg);
 } // dv_display_exit_handler 
-
-#if defined(__FreeBSD__) || defined(__APPLE__) /* We don't have on_exit() */
+#else
 static void
 xv_display_on_exit_hack_handler()
 {
@@ -650,8 +672,8 @@ xv_display_on_exit_hack_handler()
     xv_display_exit(xv_dpy_on_exit_hack);
   } /* if */
 } // xv_display_exit_handler
-#endif
-
+#endif  // ! SYS_BSD
+#endif  // unused
 
 int xv_display_init(xv_display_t *dv_dpy, int *argc, char ***argv, int width, int height, char *w_name, char *i_name, int yuv422) {
 
@@ -697,7 +719,7 @@ int xv_display_init(xv_display_t *dv_dpy, int *argc, char ***argv, int width, in
   }
 #if 0
   
-#if defined(__FreeBSD__) || defined(__APPLE__) /* We don't have on_exit() */
+#ifdef SYS_BSD /* We don't have on_exit() */
   xv_dpy_on_exit_hack = dv_dpy;
   atexit(xv_display_on_exit_hack_handler);
 #else
