@@ -5,11 +5,11 @@ int end_frame_nr;
 
 int parse_frame_entry(struct frame *pa)
 {
-int a, b, c, i, j, x, y, z;
+int a, c, i, j, x, y, z;
 char *token, *running;
-struct frame *pb;
-struct object *po;
-double da, db, dx, dy, dz;
+struct frame *pb = 0;
+struct object *po = 0;
+double da, dx, dy;
 double dgx, dgy, dgz;
 int frame_nr;
 char *cptr, *tptr;
@@ -17,11 +17,10 @@ int screen_lines;
 int line_height;
 char font_dir[4096];
 char font_name[4096];
-char temp[4096];
 font_desc_t *pfd;
 int temp_palette[16][3];
 int text_start, max_width, line_len;
-struct object *pf;
+struct object *pf = 0;
 struct object *pc;
 int bg_height, bg_width;
 
@@ -35,7 +34,7 @@ if(debug_flag)
 	pa -> name,\
 	pa -> type,\
 	pa -> end_frame,\
-	pa -> data);
+	(unsigned long)pa -> data);
 	}
 
 if(pa -> data[0] == '*')
@@ -444,7 +443,7 @@ if(pa -> data[0] == '*')
 					{
 					/* set the global for subtitles to the current value */
 					subtitle_current_font_descriptor = pb -> pfd;
-					subtitle_current_spacing = po -> extra_character_space; 
+//					subtitle_current_spacing = po -> extra_character_space; 
 					/*
 					every subtitle read from the ppml file is formatted using
 					this setting, until a line with a subtitle reference
@@ -520,6 +519,8 @@ if(pa -> data[0] == '*')
 			sscanf(token, "espace=%lf", &po -> extra_character_space);
 			sscanf(token, "despace=%lf", &po -> dextra_character_space);
 
+			sscanf(token, "anti_alias=%d", &po -> anti_alias_flag);
+
 			/* end font or text related */
 
 			/* some other commands */
@@ -635,6 +636,8 @@ if(pa -> type == FORMATTED_TEXT)
 	line_height = subtitle_current_font_descriptor -> height;
 	window_top = window_bottom - (screen_lines * line_height);
 
+//fprintf(stdout, "WAS line_height=%d\n", line_height);
+
 	if(debug_flag)
 		{
 		printf("screen_lines=%d\n", screen_lines);
