@@ -523,7 +523,7 @@ int pixels;
 
 if(debug_flag)
 	{
-	fprintf(stdout, "get_h_pixels(): arg c=%c pfd=%lu\n", c, pfd);
+	fprintf(stdout, "get_h_pixels(): arg c=%c pfd=%p\n", c, pfd);
 	}
 
 if(c < 0) c += 256;
@@ -533,8 +533,10 @@ if(c < 0x20) return 0;
 
 pixels = pfd -> width[c] + pfd -> charspace;
 
-fprintf(stdout, "WAS get_h_pixels(): extra_character_space=%d\n", extra_character_space);
-pixels += subtitle_current_spacing; //extra_character_space;
+//fprintf(stdout, "WAS get_h_pixels(): pfd->charspace=%d subtitle_extra_character_space=%.2f\n", 
+//pfd -> charspace, subtitle_extra_character_space);
+
+pixels += subtitle_extra_character_space;
 
 return pixels;
 } /* end function get_h_pixels */
@@ -570,6 +572,8 @@ if(debug_flag)
 	text, max_pixels, pfd->width['a']);
 	}
 
+//fprintf(stdout, "WAS strlen(text)=%d\n", strlen(text) );
+
 if(! text) return 0;
 
 /* in never more then this space needed */
