@@ -30,8 +30,8 @@
 
 #include "config.h"
 
-#ifdef HAVE_QT
-#include <quicktime.h>
+#ifdef HAVE_LIBQUICKTIME
+#include <quicktime/quicktime.h>
 #endif
 
 #include "transcode.h"
@@ -46,7 +46,7 @@
  * ------------------------------------------------------------*/
 
 
-#ifdef HAVE_QT
+#ifdef HAVE_LIBQUICKTIME
 void decode_mov(decode_t *decode)
 {
 
@@ -313,7 +313,7 @@ void decode_mov(decode_t *decode)
 		else
 		{
 			quicktime_close(p_qt_structure);
-			fprintf(stderr,"(%s) error: unknown format mode (0x%x) \n",__FILE__,decode->format);
+			fprintf(stderr,"(%s) error: unknown format mode (0x%x) \n",__FILE__, (unsigned int)decode->format);
 			import_exit(1);
 		}
 		quicktime_close(p_qt_structure);
