@@ -233,7 +233,7 @@ static void ps_loop (void)
 	  
 	  if((buf[3] & 0xff) == demux_track) {
 	      if (tmp1 < tmp2)
-		if (fwrite (tmp1, tmp2-tmp1, 1, stdout) != 1)
+		if (fwrite (tmp1, tmp2-tmp1, 1, out_file) != 1)
 		  import_exit(0); /* decoder exited */
 	  }
 	  buf = tmp2;
@@ -296,7 +296,7 @@ int mp3scan(int infd, int outfd)
     ++i;
     ++k;
     
-    if(sync_word == 0xfffc || sync_word == 0xfffb ) break;
+    if(sync_word == 0xfffc || sync_word == 0xfffb || sync_word == 0xfffd) break;
     
     if(k>(1<<20)) {
       fprintf(stderr, "no MP3 sync byte found within 1024 kB of stream\n");
