@@ -28,7 +28,7 @@
 #include <fcntl.h>
 #include <stdio.h>
 #include <string.h>
-
+#include <xio.h>
 #include "ioaux.h"
 #include "tc.h"
 
@@ -108,13 +108,13 @@ int save_read(char *buf, int bytes, off_t offset, int fdes)
   // returns 0 if ok, 1 on failure to read first bytes 
   
   // rewind
-  if(lseek(fdes, offset, SEEK_SET)<0) {
+  if(xio_lseek(fdes, offset, SEEK_SET)<0) {
     fprintf(stderr, "[%s:%d] ", __FILE__, __LINE__);
     perror("file seek error");
     return(1);
   }
   
-  if(read(fdes, buf, bytes)<bytes) {
+  if(xio_read(fdes, buf, bytes)<bytes) {
     fprintf(stderr, "[%s:%d] ", __FILE__, __LINE__);
     perror("file read error");
     return(1);
@@ -139,7 +139,7 @@ long fileinfo(int fdes, int skip)
   // assume this is a valid file descriptor
 
   // are we at offset defined by skip?
-  if((offset = lseek(fdes, skip, SEEK_CUR)) < 0) {
+  if((offset = xio_lseek(fdes, skip, SEEK_CUR)) < 0) {
     if(errno==ESPIPE) return(TC_MAGIC_PIPE);
     return(TC_MAGIC_ERROR);
   }
@@ -260,6 +260,13 @@ long fileinfo(int fdes, int skip)
       goto exit;
   }
 
+  // PVN image
+
+  if (strncmp (buf, "PV", 2)==0) {
+      id = TC_MAGIC_PVN;
+      goto exit;
+  }
+
   // SGI image
   
   if (cmp_16_bits(buf, TC_MAGIC_SGI)) {
@@ -285,6 +292,13 @@ long fileinfo(int fdes, int skip)
   if(save_read(buf, 4, off, fdes)) goto exit;
   
   
+  // DTS
+  
+  if(cmp_32_bits(buf, TC_MAGIC_DTS)) { 
+    id = TC_MAGIC_DTS;
+    goto exit;
+  }
+
   // VOB
   
   if(cmp_32_bits(buf, TC_MAGIC_VOB)) { 
@@ -406,15 +420,17 @@ long fileinfo(int fdes, int skip)
     id = TC_MAGIC_YUV4MPEG;
     goto exit;
   }
-
+  
   // MOV
 
-  if(strncasecmp(buf+4,"moov", 4) ==0 || strncasecmp(buf+4,"mdat", 4) ==0 ||
+  if(strncasecmp(buf+4,"moov", 4) ==0 ||
+     strncasecmp(buf+4,"cmov", 4) ==0 ||
+     strncasecmp(buf+4,"mdat", 4) ==0 ||
      strncasecmp(buf+4,"pnot", 4) ==0) {
     id = TC_MAGIC_MOV;
     goto exit;
   }
- 
+  
   // PNG
 
   if (cmp_32_bits(buf, TC_MAGIC_PNG) &&
@@ -521,6 +537,16 @@ long fileinfo(int fdes, int skip)
     goto exit;
   }
 
+  // MOV
+
+  if(strncasecmp(buf+12,"moov", 4) ==0 ||
+     strncasecmp(buf+12,"cmov", 4) ==0 ||
+     strncasecmp(buf+12,"mdat", 4) ==0 ||
+     strncasecmp(buf+12,"pnot", 4) ==0) {
+    id = TC_MAGIC_MOV;
+    goto exit;
+  }
+
   /* -------------------------------------------------------------------
    *
    * more tests
@@ -550,7 +576,7 @@ long fileinfo(int fdes, int skip)
   
  exit:
   // reset file pointer
-  lseek(fdes, 0, SEEK_SET);    
+  xio_lseek(fdes, 0, SEEK_SET);    
   return(id);
 }
 
@@ -614,6 +640,13 @@ long streaminfo(int fdes)
    *
    *-------------------------------------------------------------------*/
   
+  // DTS
+  
+  if(cmp_32_bits(buf, TC_MAGIC_DTS)) { 
+    id = TC_MAGIC_DTS;
+    goto exit;
+  }
+
   // VOB
   
   if(cmp_32_bits(buf, TC_MAGIC_VOB)) { 
@@ -711,7 +744,10 @@ long streaminfo(int fdes)
   
   // MOV
 
-  if(strncasecmp(buf+4,"moov",4) ==0 ) {
+  if(strncasecmp(buf+4,"moov", 4) ==0 ||
+     strncasecmp(buf+4,"cmov", 4) ==0 ||
+     strncasecmp(buf+4,"mdat", 4) ==0 ||
+     strncasecmp(buf+4,"pnot", 4) ==0) {
     id = TC_MAGIC_MOV;
     goto exit;
   }
@@ -793,6 +829,7 @@ char *filetype(long magic)
   case TC_MAGIC_GIF:          return("GIF image");
   case TC_MAGIC_PPM:          return("PPM image");
   case TC_MAGIC_PGM:          return("PGM image");
+  case TC_MAGIC_PVN:          return("PVN video");
   case TC_MAGIC_SGI:          return("SGI image");
   case TC_MAGIC_RMF:          return("Real Media");
   case TC_MAGIC_XML:          return("XML file, need to analyze the content");
@@ -802,6 +839,7 @@ char *filetype(long magic)
 
   case TC_MAGIC_RAW:          return("RAW stream");
   case TC_MAGIC_AC3:          return("AC3 stream");
+  case TC_MAGIC_DTS:          return("DTS stream");
   case TC_MAGIC_MP3:          return("MPEG-1 layer-3 stream");
   case TC_MAGIC_MP3_2:        return("MPEG-2 layer-3 stream");
   case TC_MAGIC_MP3_2_5:      return("MPEG-2.5 layer-3 stream");
