@@ -25,19 +25,19 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
-#include "avilib.h"
 #include "transcode.h"
+#include <xio.h>
 
 #define MOD_NAME    "import_avi.so"
 #define MOD_VERSION "v0.4.2 (2002-05-24)"
 #define MOD_CODEC   "(video) * | (audio) *"
 
-#define MOD_PRE avi
-#include "import_def.h"
-
 static int verbose_flag=TC_QUIET;
 static int capability_flag=TC_CAP_PCM|TC_CAP_RGB|TC_CAP_AUD|TC_CAP_VID|TC_CAP_YUV422;
 
+#define MOD_PRE avi
+#include "import_def.h"
+
 static avi_t *avifile1=NULL;
 static avi_t *avifile2=NULL;
 
@@ -70,7 +70,7 @@ MOD_open
     // Is the input file actually a directory - if so use
     // tccat to dump out the audio. N.B. This isn't going
     // to work if a particular track is needed
-    if((stat(vob->audio_in_file, &fbuf))==0 && S_ISDIR(fbuf.st_mode)) {
+    if((xio_stat(vob->audio_in_file, &fbuf))==0 && S_ISDIR(fbuf.st_mode)) {
       sprintf(import_cmd_buf, "tccat -a -i \"%s\" -d %d", vob->video_in_file, vob->verbose);
       if(verbose_flag) printf("[%s] %s\n", MOD_NAME, import_cmd_buf);
       if ((param->fd = popen(import_cmd_buf, "r"))== NULL) {
@@ -234,7 +234,6 @@ MOD_decode
     case CODEC_RAW:
     
       bytes_read = AVI_audio_size(avifile1, aframe_count);
-      fprintf(stderr, "  XXX bytes_read = %ld|\n", bytes_read);
 
       if(bytes_read<0) {
 	if(verbose & TC_DEBUG) AVI_print_error("AVI audio size frame");
