@@ -35,7 +35,7 @@
 #include <dlfcn.h>
 #else
 # ifdef SYSTEM_DARWIN
-#  include "../libdldarwin/dlfcn.h"
+#  include "libdldarwin/dlfcn.h"
 # endif
 #endif
 
@@ -55,14 +55,15 @@
 #define MOD_NAME    "import_divx.so"
 #define MOD_VERSION "v0.2.9 (2003-07-30)"
 #define MOD_CODEC   "(video) DivX;-)/XviD/OpenDivX/DivX 4.xx/5.xx"
+
+static int verbose_flag=TC_QUIET;
+static int capability_flag=TC_CAP_RGB|TC_CAP_YUV|TC_CAP_VID;
+
 #define MOD_PRE divx
 #include "import_def.h"
 
 #define MAX_BUF 1024
 char import_cmd_buf[MAX_BUF];
-
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_RGB|TC_CAP_YUV|TC_CAP_VID;
 static int codec, frame_size=0;
 static unsigned long divx_version=DEC_OPT_FRAME;
 
@@ -104,7 +105,6 @@ static int pass_through=0, pass_through_decode=0;
 
 //temporary video buffer
 static char *buffer = NULL;
-#define BUFFER_SIZE SIZE_RGB_FRAME
 
 
 inline static int stream_read_char(char *d)
@@ -181,7 +181,7 @@ static unsigned char *bufalloc(size_t size)
 }
 
 static int divx_init(char *path) {
-#ifdef __FreeBSD__
+#ifdef SYS_BSD
     const
 #endif    
     char *error;
@@ -367,6 +367,7 @@ MOD_open
     pbi->biWidth = AVI_video_width(avifile);
     pbi->biHeight = AVI_video_height(avifile);
 
+    frame_size = pbi->biWidth * pbi->biHeight * 3;
     switch(codec) {
       
     case CODEC_RGB:
@@ -399,6 +400,7 @@ MOD_open
 
     
 #else
+    frame_size = divx->x_dim * divx->y_dim * 3;
     switch(codec) {
       
     case CODEC_RGB:
@@ -466,12 +468,12 @@ MOD_open
     }
   
     if (!buffer) {
-      if ((buffer = bufalloc(BUFFER_SIZE))==NULL) {
+      if ((buffer = bufalloc(frame_size))==NULL) {
 	perror("out of memory");
 	return(TC_EXPORT_ERROR); 
       } 
       else {
-	memset(buffer, 0, BUFFER_SIZE);
+	memset(buffer, 0, frame_size);
       }
     }
     
@@ -588,7 +590,7 @@ MOD_decode {
 #endif
       
       param->size = frame_size;
-      memcpy(param->buffer, working_frame, frame_size);
+      tc_memcpy(param->buffer, working_frame, frame_size);
     }
     
     //for preview/pass-through feature
@@ -615,7 +617,7 @@ MOD_decode {
 	  return(TC_IMPORT_ERROR); 
       }
 #endif
-      memcpy(param->buffer2, working_frame, frame_size);
+      tc_memcpy(param->buffer2, working_frame, frame_size);
     }
     
     return(0);
