@@ -25,13 +25,16 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
-
+#include <xio.h>
 #include "transcode.h"
 
 #define MOD_NAME    "import_mp3.so"
 #define MOD_VERSION "v0.1.4 (2003-08-04)"
 #define MOD_CODEC   "(audio) MPEG"
 
+static int verbose_flag=TC_QUIET;
+static int capability_flag=TC_CAP_PCM;
+
 #define MOD_PRE mp3
 #include "import_def.h"
 
@@ -40,9 +43,6 @@ char import_cmd_buf[MAX_BUF];
 
 static FILE *fd;
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_PCM;
-
 static int codec;
 
 static int count=TC_PAD_AUD_FRAMES;
@@ -54,7 +54,7 @@ static int scan(char *name)
 {
   struct stat fbuf;
   
-  if(stat(name, &fbuf)) {
+  if(xio_stat(name, &fbuf)) {
     fprintf(stderr, "(%s) invalid file \"%s\"\n", __FILE__, name);
     exit(1);
   }
