@@ -32,15 +32,15 @@
 #define MOD_VERSION "v0.4.0 (2003-10-02)"
 #define MOD_CODEC   "(video) MPEG2"
 
+static int verbose_flag=TC_QUIET;
+static int capability_flag=TC_CAP_RGB|TC_CAP_YUV|TC_CAP_VID;
+
 #define MOD_PRE mpeg2
 #include "import_def.h"
 
 #define MAX_BUF 1024
 char import_cmd_buf[MAX_BUF];
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_RGB|TC_CAP_YUV|TC_CAP_VID;
-
 typedef struct tbuf_t {
 	int off;
 	int len;
@@ -208,7 +208,7 @@ MOD_decode{
 	    param->size = tbuf.off-start_seq;
 
 	    // spit frame out
-	    memcpy(param->buffer, tbuf.d+start_seq, param->size);
+	    tc_memcpy(param->buffer, tbuf.d+start_seq, param->size);
 	    memmove(tbuf.d, tbuf.d+param->size, tbuf.len-param->size);
 	    tbuf.off = 0;
 	    tbuf.len -= param->size;
@@ -256,7 +256,7 @@ MOD_decode{
 	    if (pic_type == 2) param->attributes |= TC_FRAME_IS_P_FRAME;
 	    if (pic_type == 3) param->attributes |= TC_FRAME_IS_B_FRAME;
 
-	    memcpy(param->buffer, tbuf.d+start_pic, param->size);
+	    tc_memcpy(param->buffer, tbuf.d+start_pic, param->size);
 	    memmove(tbuf.d, tbuf.d+param->size, tbuf.len-param->size);
 	    tbuf.off = 0;
 	    tbuf.len -= param->size;
@@ -275,7 +275,7 @@ MOD_decode{
 	      if (pic_type == 2) param->attributes |= TC_FRAME_IS_P_FRAME;
 	      if (pic_type == 3) param->attributes |= TC_FRAME_IS_B_FRAME;
 
-	      memcpy(param->buffer, tbuf.d+start_pic, param->size);
+	      tc_memcpy(param->buffer, tbuf.d+start_pic, param->size);
 	      memmove(tbuf.d, tbuf.d+param->size, tbuf.len-param->size);
 	      tbuf.off = 0;
 	      tbuf.len -= param->size;
