@@ -34,6 +34,10 @@
 #define MOD_VERSION "v0.6.0 (2003-10-02)"
 #define MOD_CODEC   "(video) MPEG-2 | (audio) MPEG/AC3/PCM | (subtitle)"
 
+static int verbose_flag=TC_QUIET;
+static int capability_flag=TC_CAP_VID|TC_CAP_RGB|TC_CAP_YUV|TC_CAP_PCM|TC_CAP_AC3;
+
+
 #define MOD_PRE vob
 #include "import_def.h"
 
@@ -52,9 +56,6 @@ static tbuf_t tbuf;
 static int m2v_passthru=0;
 static FILE *f; // video fd
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_VID|TC_CAP_RGB|TC_CAP_YUV|TC_CAP_PCM|TC_CAP_AC3;
-
 static int codec, syncf=0;
 static int pseudo_frame_size=0, real_frame_size=0, effective_frame_size=0;
 static int ac3_bytes_to_go=0;
@@ -89,18 +90,10 @@ MOD_open
       
     case CODEC_AC3:
       
-#if 1
       if((snprintf(import_cmd_buf, MAX_BUF, "tccat -i \"%s\" -t vob -d %d -S %d | tcdemux -a %d -x ac3 %s %s -d %d | tcextract -t vob -a %d -x ac3 -d %d | tcextract -t raw -x ac3 -d %d", vob->audio_in_file, vob->verbose, vob->vob_offset, vob->a_track, seq_buf, dem_buf, vob->verbose, vob->a_track, vob->verbose, vob->verbose)<0)) {
 	perror("command buffer overflow");
 	return(TC_IMPORT_ERROR);
       }
-#else
-
-      if((snprintf(import_cmd_buf, MAX_BUF, "tccat -i \"%s\" -t vob -d %d -S %d | tcdemux -a %d -x ac3 %s %s -d %d | tcextract -t vob -a %d -x ac3 -d %d | tcdecode -y raw -x a52 -d %d -A %d", vob->audio_in_file, vob->verbose, vob->vob_offset, vob->a_track, seq_buf, dem_buf, vob->verbose, vob->a_track, vob->verbose, vob->verbose, vob->a52_mode)<0)) {
-	perror("command buffer overflow");
-	return(TC_IMPORT_ERROR);
-      }
-#endif
       
       if(verbose_flag & TC_DEBUG) printf("[%s] AC3->AC3\n", MOD_NAME);
       
@@ -391,7 +384,7 @@ MOD_decode
 	      param->size = tbuf.off-start_seq;
 
 	      // spit frame out
-	      memcpy(param->buffer, tbuf.d+start_seq, param->size);
+	      tc_memcpy(param->buffer, tbuf.d+start_seq, param->size);
 	      memmove(tbuf.d, tbuf.d+param->size, tbuf.len-param->size);
 	      tbuf.off = 0;
 	      tbuf.len -= param->size;
@@ -439,7 +432,7 @@ MOD_decode
 	      if (pic_type == 2) param->attributes |= TC_FRAME_IS_P_FRAME;
 	      if (pic_type == 3) param->attributes |= TC_FRAME_IS_B_FRAME;
 
-	      memcpy(param->buffer, tbuf.d+start_pic, param->size);
+	      tc_memcpy(param->buffer, tbuf.d+start_pic, param->size);
 	      memmove(tbuf.d, tbuf.d+param->size, tbuf.len-param->size);
 	      tbuf.off = 0;
 	      tbuf.len -= param->size;
@@ -458,7 +451,7 @@ MOD_decode
 		 if (pic_type == 2) param->attributes |= TC_FRAME_IS_P_FRAME;
 		 if (pic_type == 3) param->attributes |= TC_FRAME_IS_B_FRAME;
 
-		 memcpy(param->buffer, tbuf.d+start_pic, param->size);
+		 tc_memcpy(param->buffer, tbuf.d+start_pic, param->size);
 		 memmove(tbuf.d, tbuf.d+param->size, tbuf.len-param->size);
 		 tbuf.off = 0;
 		 tbuf.len -= param->size;
