@@ -32,6 +32,7 @@
 #define TC_CODEC_RGB                   0x00000024
 #define TC_CODEC_AC3                   0x00002000
 #define TC_CODEC_A52                   0x00002001
+#define TC_CODEC_DTS                   0x0001000f
 #define TC_CODEC_YV12                  0x32315659
 #define TC_CODEC_UYVY                  0x59565955
 #define TC_CODEC_YUV2                  0x32565559
@@ -115,6 +116,7 @@
 #define TC_MAGIC_DV_PAL                0x1f0700bf
 #define TC_MAGIC_DV_NTSC               0x1f07003f
 #define TC_MAGIC_AC3                   0x00000b77
+#define TC_MAGIC_DTS                   0x7ffe8001
 #define TC_MAGIC_LPCM                  0x00000180
 #define TC_MAGIC_MP3                   0x0000FFFB
 #define TC_MAGIC_MP2_FC                0x0000FFFC
@@ -129,6 +131,7 @@
 #define TC_MAGIC_SGI                   0x000001DA
 #define TC_MAGIC_PNG                   0x89504e47
 #define TC_MAGIC_GIF                   0x00474946
+#define TC_MAGIC_PVN                   0x00005037
 #define TC_MAGIC_PPM                   0x00005036
 #define TC_MAGIC_PGM                   0x00005035
 #define TC_MAGIC_ID3                   0x49443303
