@@ -28,6 +28,9 @@
 #endif
 #endif
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 #ifdef	__linux__
 #include <features.h>
 #endif
@@ -55,6 +58,8 @@ extern "C" {
 #endif
 #include "minilzo.h"
 
+#include "transcode.h"
+
 
 /*
   int    rtjpeg_aud_file;
@@ -108,7 +113,7 @@ int rtjpeg_aud_open(char *tplorg)
     regions[0].end   = -1;
   }
 
-#if defined(__FreeBSD__) || defined(__APPLE__) 
+#ifdef SYS_BSD
   rtjpeg_aud_file=open(tplorg, O_RDONLY);
 #else 
   rtjpeg_aud_file=open(tplorg, O_RDONLY|O_LARGEFILE);
@@ -450,7 +455,7 @@ unsigned char *decode_aud_frame(struct rtframeheader *frameheader,unsigned char
 
   // raw YUV420 (I420, YCrCb) uncompressed
   if (frameheader->frametype=='V' && frameheader->comptype == '0') {
-    memcpy(buf2, strm, (int)(rtjpeg_aud_video_width*rtjpeg_aud_video_height*1.5)); // save for 'L'
+    tc_memcpy(buf2, strm, (int)(rtjpeg_aud_video_width*rtjpeg_aud_video_height*1.5)); // save for 'L'
     return(buf2);
   }
  
@@ -689,8 +694,8 @@ unsigned char *rtjpeg_aud_get_frame(int fakenumber, int *timecode, int onlyvideo
           } else {
             //fprintf(stderr, "timecode shift=%d atc=%d vtc=%d\n", ashift, audiotimecode, 
             //                timecodes[rpos]);
-            memcpy(tmpaudio, audiobuffer, audiolen);
-            memcpy(audiobuffer, tmpaudio+ashift, audiolen);
+            tc_memcpy(tmpaudio, audiobuffer, audiolen);
+            tc_memcpy(audiobuffer, tmpaudio+ashift, audiolen);
             audiolen -= ashift;
           }
         }
@@ -705,9 +710,9 @@ unsigned char *rtjpeg_aud_get_frame(int fakenumber, int *timecode, int onlyvideo
           } else {
             //fprintf(stderr, "timecode shift=%d atc=%d vtc=%d\n", -ashift, audiotimecode, 
             //                timecodes[rpos]);
-            memcpy(tmpaudio, audiobuffer, audiolen);
+            tc_memcpy(tmpaudio, audiobuffer, audiolen);
             bzero(audiobuffer, ashift); // silence!
-            memcpy(audiobuffer+ashift, tmpaudio, audiolen);
+            tc_memcpy(audiobuffer+ashift, tmpaudio, audiolen);
             audiolen += ashift;
           }
         }
@@ -753,7 +758,7 @@ unsigned char *rtjpeg_aud_get_frame(int fakenumber, int *timecode, int onlyvideo
         ret = vbuffer[0]; // we don't decode video for exporting audio only
       }
       // now buffer it
-      memcpy(vbuffer[wpos], ret, (int)(rtjpeg_aud_video_width*rtjpeg_aud_video_height*1.5));
+      tc_memcpy(vbuffer[wpos], ret, (int)(rtjpeg_aud_video_width*rtjpeg_aud_video_height*1.5));
       timecodes[wpos] = frameheader.timecode;
       bufstat[wpos]=1;
       //lastwpos=wpos;
@@ -768,7 +773,7 @@ unsigned char *rtjpeg_aud_get_frame(int fakenumber, int *timecode, int onlyvideo
         memset(strm,   0, lastaudiolen);
       } 
       // now buffer it
-      memcpy(audiobuffer+audiolen, strm, frameheader.packetlength);
+      tc_memcpy(audiobuffer+audiolen, strm, frameheader.packetlength);
       audiotimecode = frameheader.timecode + rtjpeg_aud_audiodelay; // untested !!!! possible FIXME
       if (audiolen>0) {
         // now we take the new timecode and calculate the shift
@@ -791,8 +796,8 @@ unsigned char *rtjpeg_aud_get_frame(int fakenumber, int *timecode, int onlyvideo
     *alen = 0;
   } else {
     *alen = bytesperframe;
-    memcpy(tmpaudio, audiobuffer, audiolen);
-    memcpy(audiobuffer, tmpaudio+bytesperframe, audiolen);
+    tc_memcpy(tmpaudio, audiobuffer, audiolen);
+    tc_memcpy(audiobuffer, tmpaudio+bytesperframe, audiolen);
     audiolen -= bytesperframe;
     audiobytes += bytesperframe;
   }
