@@ -373,7 +373,7 @@ void scan_pes(int verbose, FILE *in_file)
 		mpeg_version=2;
 
 		// get pts time stamp:
-		memcpy(scan_buf, &buf[6], 16);
+		tc_memcpy(scan_buf, &buf[6], 16);
 		has_pts_dts=get_pts_dts(scan_buf, &i_pts, &i_dts);
 		
 		if(has_pts_dts) {
@@ -426,7 +426,7 @@ void scan_pes(int verbose, FILE *in_file)
 	      }
 
 	      // get pts time stamp:
-	      memcpy(scan_buf, &buf[6], 16);
+	      tc_memcpy(scan_buf, &buf[6], 16);
 	      has_pts_dts=get_pts_dts(scan_buf, &i_pts, &i_dts);
 	      
 	      if(has_pts_dts) {
@@ -616,7 +616,7 @@ void probe_pes(info_t *ipipe)
 	    
 	    // get PPP - starts
 	    
-	    memcpy(scan_buf, &buf[4], 16);
+	    tc_memcpy(scan_buf, &buf[4], 16);
 	    pack_pts_2 = read_time_stamp_long(scan_buf);
 	    pack_ppp = read_time_stamp(scan_buf);
 
@@ -685,7 +685,7 @@ void probe_pes(info_t *ipipe)
 		ipipe->probe_info->codec=TC_CODEC_MPEG2;
 
 		// get pts time stamp:
-		memcpy(scan_buf, &buf[6], 16);
+		tc_memcpy(scan_buf, &buf[6], 16);
 		has_pts_dts=get_pts_dts(scan_buf, &i_pts, &i_dts);
 		
 		if(has_pts_dts) {
@@ -769,7 +769,7 @@ void probe_pes(info_t *ipipe)
 	      }
 
 	      // get pts time stamp:
-	      memcpy(scan_buf, &buf[6], 16);
+	      tc_memcpy(scan_buf, &buf[6], 16);
 	      has_pts_dts=get_pts_dts(scan_buf, &i_pts, &i_dts);
 
 	      if(has_pts_dts) {
@@ -854,7 +854,7 @@ void probe_pes(info_t *ipipe)
 		  ipipe->probe_info->track[num].attribute |= PACKAGE_SUBTITLE;
 
 		  // get pts time stamp:
-		  memcpy(scan_buf, &buf[6], 16);
+		  tc_memcpy(scan_buf, &buf[6], 16);
 		  has_pts_dts=get_pts_dts(scan_buf, &i_pts, &i_dts);
 		}
 	      }
@@ -866,7 +866,7 @@ void probe_pes(info_t *ipipe)
 	    //
 	    //-------------
 
-	    if((aid >= 0x80) && (aid <= 0x9F)) {
+	    if(((aid >= 0x80 && aid <= 0x88)) || (aid>=0x90 && aid<=0x9f)) {
 	      num=aid-0x80;
 	      
 	      if(!(attr[num] & PACKAGE_AUDIO_AC3) && initial_sync) {
@@ -886,7 +886,75 @@ void probe_pes(info_t *ipipe)
 		  ret = buf_probe_ac3(tmp1, tmp2-tmp1, &ipipe->probe_info->track[num]);
 		  if(ret==0) {
 		    ipipe->probe_info->track[num].attribute |= PACKAGE_AUDIO_AC3;
-		    memcpy(scan_buf, &buf[6], 16);
+		    tc_memcpy(scan_buf, &buf[6], 16);
+		    has_pts_dts=get_pts_dts(scan_buf, &i_pts, &i_dts);
+		    ipipe->probe_info->track[num].pts_start=(double) i_pts/90000.;
+		    has_audio=1;
+		  }
+		}
+	      }
+	    }
+
+	    //-------------
+	    //
+	    // DTS audio
+	    //
+	    //-------------
+
+	    if((aid >= 0x89) && (aid <= 0x8f)) {
+	      num=aid-0x80;
+	      
+	      if(!(attr[num] & PACKAGE_AUDIO_DTS) && initial_sync) {
+		
+		if(!track[num]) {
+		  ++ipipe->probe_info->num_tracks;
+		  track[num]=1;
+		  ipipe->probe_info->track[num].tid=num;
+		}
+		
+		if(!(ipipe->probe_info->track[num].attribute &
+		     PACKAGE_AUDIO_DTS)) {
+
+			tmp1+=4;
+
+		  //need to scan payload for more DTS audio info
+		  ipipe->probe_info->track[num].attribute |= PACKAGE_AUDIO_DTS;
+		  buf_probe_dts(tmp1, tmp2-tmp1, &ipipe->probe_info->track[num]);
+
+		  tc_memcpy(scan_buf, &buf[6], 16);
+		  has_pts_dts=get_pts_dts(scan_buf, &i_pts, &i_dts);
+		  ipipe->probe_info->track[num].pts_start=(double) i_pts/90000.;
+		  has_audio=1;
+	      }
+	    }
+		}
+	    //-------------
+	    //
+	    //AC3 audio
+	    //
+	    //-------------
+
+	    if((aid >= 0x80) && (aid <= 0x88)) {
+	      num=aid-0x80;
+	      
+	      if(!(attr[num] & PACKAGE_AUDIO_AC3) && initial_sync) {
+		
+		if(!track[num]) {
+		  ++ipipe->probe_info->num_tracks;
+		  track[num]=1;
+		  ipipe->probe_info->track[num].tid=num;
+		}
+		
+		if(!(ipipe->probe_info->track[num].attribute &
+		     PACKAGE_AUDIO_AC3)) {
+		  
+		  tmp1 +=4;
+		  
+		  //need to scan payload for more AC3 audio info
+		  ret = buf_probe_ac3(tmp1, tmp2-tmp1, &ipipe->probe_info->track[num]);
+		  if(ret==0) {
+		    ipipe->probe_info->track[num].attribute |= PACKAGE_AUDIO_AC3;
+		    tc_memcpy(scan_buf, &buf[6], 16);
 		    has_pts_dts=get_pts_dts(scan_buf, &i_pts, &i_dts);
 		    ipipe->probe_info->track[num].pts_start=(double) i_pts/90000.;
 		    has_audio=1;
@@ -914,16 +982,39 @@ void probe_pes(info_t *ipipe)
 
 		if(!(ipipe->probe_info->track[num].attribute &
 		     PACKAGE_AUDIO_PCM)) {
+
+		  tmp1 += 4;
+
 		  ipipe->probe_info->track[num].attribute |= PACKAGE_AUDIO_PCM;
 
-		  //FIXME: need to read header
-		  ipipe->probe_info->track[num].samplerate=48000;
-		  ipipe->probe_info->track[num].bits=16;
-		  ipipe->probe_info->track[num].chan=2;
-		  ipipe->probe_info->track[num].bitrate=1536;
+		  switch ((tmp1[1] >> 4) & 3) {
+		  case 0: ipipe->probe_info->track[num].samplerate = 48000;
+			  break;
+		  case 1: ipipe->probe_info->track[num].samplerate = 96000;
+			  break;
+		  case 2: ipipe->probe_info->track[num].samplerate = 44100;
+			  break;
+		  case 3: ipipe->probe_info->track[num].samplerate = 32000;
+			  break;
+		  }
+		  switch ((tmp1[1] >> 6) & 3) {
+		  case 0: ipipe->probe_info->track[num].bits = 16;
+			  break;
+		  case 1: ipipe->probe_info->track[num].bits = 20;
+			  break;
+		  case 2: ipipe->probe_info->track[num].bits = 24;
+			  break;
+		  default: fprintf (stderr, "unknown LPCM quantization\n");
+			  import_exit (1);
+		  }
+		  ipipe->probe_info->track[num].chan = 1 + (tmp1[1] & 7);
+		  ipipe->probe_info->track[num].bitrate
+		    = ipipe->probe_info->track[num].samplerate
+		      * ipipe->probe_info->track[num].bits
+		      * ipipe->probe_info->track[num].chan / 1000;
 		  ipipe->probe_info->track[num].format=CODEC_LPCM;
 
-		  memcpy(scan_buf, &buf[6], 16);
+		  tc_memcpy(scan_buf, &buf[6], 16);
 		  has_pts_dts=get_pts_dts(scan_buf, &i_pts, &i_dts);
 		  ipipe->probe_info->track[num].pts_start=(double) i_pts/90000.;
 		  has_audio=1;
@@ -1004,7 +1095,7 @@ void probe_pes(info_t *ipipe)
 	    
 	    ++ipipe->probe_info->num_tracks;
 	    
-#ifdef LAME_3_89
+#ifdef HAVE_LAME
 	    //need to scan payload for more MPEG audio info
 	    if(end-buf>0) buf_probe_mp3(buf, end-buf, &ipipe->probe_info->track[num]);
 #else
@@ -1013,7 +1104,7 @@ void probe_pes(info_t *ipipe)
 	    ipipe->probe_info->track[num].tid=num;
 #endif
 	    
-	    memcpy(scan_buf, &buf[6], 16);
+	    tc_memcpy(scan_buf, &buf[6], 16);
 	    has_pts_dts=get_pts_dts(scan_buf, &i_pts, &i_dts);
 	    
 	    if(has_pts_dts) {
