@@ -27,7 +27,7 @@
 #include <sys/errno.h>
 #include <errno.h>
 #include <unistd.h>
-
+#include <xio.h>
 #include "transcode.h"
 #include "ioaux.h"
 #include "tc.h"
@@ -38,7 +38,6 @@
 #define MAX_BUF     1024
 
 void tcdemux_pass_through(info_t *ipipe, int *pass);
-
 static int verbose=TC_QUIET;
 
 /* ------------------------------------------------------------ 
@@ -123,6 +122,8 @@ int main(int argc, char *argv[])
     //defaults:
     int unit_seek=0, resync_seq1=0, resync_seq2=INT_MAX;
 
+	tc_memcpy_init(verbose & TC_INFO, -1);
+
     //proper initialization
     memset(&ipipe, 0, sizeof(info_t));
 
@@ -318,7 +319,7 @@ int main(int argc, char *argv[])
       
       if(file_check(name)) exit(1);
       
-      if((ipipe.fd_in = open(name, O_RDONLY))<0) {
+      if((ipipe.fd_in = xio_open(name, O_RDONLY))<0) {
 	perror("open file");
 	exit(1);
       } 
@@ -370,3 +371,4 @@ int main(int argc, char *argv[])
     return(0);
 }
 
+#include "libxio/static_xio.h"
