@@ -100,6 +100,9 @@ void usage(int status)
 
 int f_init_func(char *p_option,char *p_mod)
 {
+#ifdef SYS_BSD
+	const
+#endif
 	char *p_error;
 	char *p_modpath=MOD_PATH;
 	char s_module[MAX_BUF];
