@@ -28,7 +28,7 @@
 #include <dlfcn.h>
 #else
 # ifdef SYSTEM_DARWIN
-#  include "../libdldarwin/dlfcn.h"
+#  include "libdldarwin/dlfcn.h"
 # endif
 #endif
 
@@ -128,7 +128,7 @@ int tca_import(int opt, void *para1, void *para2)
 
 void *load_module(char *mod_name, int mode)
 {
-#if defined(__FreeBSD__) || defined (__APPLE__)
+#ifdef SYS_BSD
   const
 #endif  
   char *error;
@@ -144,14 +144,16 @@ void *load_module(char *mod_name, int mode)
     handle = dlopen(module, RTLD_GLOBAL| RTLD_LAZY);
     
     if (!handle) {
-      tc_warn("%s", dlerror());
+      error=dlerror();
+      tc_warn("%s", error);
       tc_warn("(%s) loading \"%s\" failed", __FILE__, module);
       return(NULL);
     }
     
     if(mode & TC_VIDEO) {
       TCV_export = dlsym(handle, "tc_export");   
-      if ((error = dlerror()) != NULL)  {
+      error = dlerror();
+      if (error != NULL)  {
 	tc_warn("%s", error);
 	return(NULL);
       }
@@ -159,7 +161,8 @@ void *load_module(char *mod_name, int mode)
     
     if(mode & TC_AUDIO) {
       TCA_export = dlsym(handle, "tc_export");   
-      if ((error = dlerror()) != NULL)  {
+      error = dlerror();
+      if (error != NULL)  {
 	tc_warn("%s", error);
 	return(NULL);
       }
@@ -179,7 +182,8 @@ void *load_module(char *mod_name, int mode)
     handle = dlopen(module, RTLD_GLOBAL| RTLD_LAZY);
     
     if (!handle) {
-      tc_warn("%s", dlerror());
+      error = dlerror();
+      tc_warn("%s", error);
       return(NULL);
     }
     
