@@ -35,7 +35,7 @@
 #include <dlfcn.h>
 #else
 # ifdef SYSTEM_DARWIN
-#  include "../libdldarwin/dlfcn.h"
+#  include "libdldarwin/dlfcn.h"
 # endif
 #endif
 
@@ -127,7 +127,7 @@ int filter_unquote_options(char *options)
 }
 
 int load_plugin(char *path) {
-#if defined(__FreeBSD__) || defined (__APPLE__)
+#ifdef SYS_BSD
   const
 #endif    
   char *error;
@@ -380,7 +380,7 @@ char *get_next_filter_name(char **name, int *namelen, char *string)
 	  len = *namelen;
 	  *name = (char *)malloc(len+2);
 	  memset(*name, 0, len+2);
-	  memcpy(*name, string, len);
+	  tc_memcpy(*name, string, len);
 
 	  //return pointer to '\0'
 	  return(string+strlen(string));
@@ -399,7 +399,7 @@ char *get_next_filter_name(char **name, int *namelen, char *string)
   *name = (char *)malloc(len+2);
 
   memset(*name, 0, len+2);
-  memcpy(*name, string, len);
+  tc_memcpy(*name, string, len);
   
   return(res+1);
 }
