@@ -92,13 +92,20 @@
         - Added implementation of getopt() if compiling under Windows.
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#if !defined(__FreeBSD__) && !defined(__APPLE__)
-#include <malloc.h>
+#ifndef SYS_BSD
+# ifdef HAVE_MALLOC_H
+# include <malloc.h>
+# endif
 #endif
 #include <math.h>
+#include <inttypes.h>
 
 #include "zoom.h"
 
@@ -111,10 +118,19 @@
 
 #define WHITE_PIXEL (255)
 #define BLACK_PIXEL (0)
+#if 0
 #define CLAMP(v) (((v) < (BLACK_PIXEL)) ? \
                   (BLACK_PIXEL) :  \
                   (((v) > (WHITE_PIXEL)) ? (WHITE_PIXEL) : (v)))
-
+#else
+static inline uint8_t CLAMP(uint32_t v) {
+    // negative will be clipped to 1
+    v >>= ((v&0xF8000000)>>27);
+    // >255 -> 255.
+    v |= (v>>8)*0xff;
+    return v&0xff;
+}
+#endif
 
 #define get_pixel(image, y, x) ((image)->data[(x) + (y) * image->span])
 #define put_pixel(image, y, x, p) ((image)->data[(x) + (y) * image->span] = (p))
@@ -311,7 +327,7 @@ int i;                      * pixel_t column in source bitmap being processed */
         center = (double) i / xscale;
         left = ceil(center - width);
         right = floor(center + width);
-        for(j = (int)left; j <= right; ++j)
+        for(j = (int)left; j <= (int)right; ++j)
         {
             weight = center - (double) j;
             weight = (*filterf)(weight / fscale) / fscale;
@@ -340,7 +356,7 @@ int i;                      * pixel_t column in source bitmap being processed */
         left = ceil(center - fwidth);
         right = floor(center + fwidth);
 
-        for(j = (int)left; j <= right; ++j)
+        for(j = (int)left; j <= (int)right; ++j)
         {
             weight = center - (double) j;
             weight = (*filterf)(weight);
@@ -377,7 +393,7 @@ zoom_image_init(image_t *dst, image_t *src, double (*filterf)(double), double fw
     CLIST  contribX;
     CLIST *contribY;
     instruction_t *prg;
-    
+
     zoomer = (zoomer_t*)malloc(sizeof(zoomer_t));
     zoomer->src = src;
     zoomer->dst = dst;
@@ -422,7 +438,7 @@ zoom_image_init(image_t *dst, image_t *src, double (*filterf)(double), double fw
             center = (double) i / yscale;
             left = ceil(center - width);
             right = floor(center + width);
-            for(j = (int)left; j <= right; ++j) {
+            for(j = (int)left; j <= (int)right; ++j) {
                 weight = center - (double) j;
                 weight = (*filterf)(weight / fscale) / fscale;
                 if(j < 0) {
@@ -450,7 +466,7 @@ zoom_image_init(image_t *dst, image_t *src, double (*filterf)(double), double fw
             center = (double) i / yscale;
             left = ceil(center - fwidth);
             right = floor(center + fwidth);
-            for(j = (int)left; j <= right; ++j) {
+            for(j = (int)left; j <= (int)right; ++j) {
                 weight = center - (double) j;
                 weight = (*filterf)(weight);
                 if(j < 0) {
