@@ -29,8 +29,10 @@
 #include <fcntl.h>
 #include <string.h>
 
-#include "avilib.h"
+#include "transcode.h"
+
 #include "config.h"
+#include "avilib.h"
 
 #define EXE "avifix"
 
@@ -54,10 +56,8 @@ void usage(int status)
     exit(status);
 }
 
-
 int main(int argc, char *argv[])
 {
-
   struct common_struct rtf;
   struct AVIStreamHeader ash, vsh;
 
@@ -81,6 +81,8 @@ int main(int argc, char *argv[])
 
   char *filename=NULL;
 
+  tc_memcpy_init(0, -1);
+
   if(argc==1) usage(EXIT_FAILURE);
   
   while ((ch = getopt(argc, argv, "f:i:N:F:vb:e:a:?h")) != -1)
