@@ -29,8 +29,10 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <string.h>
+#include <inttypes.h>
+
+#include "xio.h"
 
-#include "avilib.h"
 #include "config.h"
 #include "transcode.h"
 
@@ -48,9 +50,15 @@ void usage(int status)
 {
   version();
   printf("\nUsage: %s [options]\n", EXE);
-  printf("\t -o file            output file\n");
-  printf("\t -i file            input file\n");
-  printf("\t -n                 read index in \"smart\" mode\n");
+  printf("\t -o file   output file\n");
+  printf("\t -i file   input file\n");
+  printf("\t -f        force the use of the existing index\n");
+  printf("\t           only to use when avi > 2GB, because\n");
+  printf("\t           the default is to -n with big files\n");
+  printf("\t -n        read index in \"smart\" mode: don't use the existing index\n");
+  printf("\t -x        don't use the existing index to generate the keyframes\n");
+  printf("\t           this flag forces -n\n");
+  printf("\t -v        print version\n");
   exit(status);
 }
 
@@ -62,10 +70,173 @@ static unsigned long str2ulong(unsigned char *str)
 
 #define AVI_MAX_LEN (UINT_MAX-(1<<20)*16-2048)
 
+static inline uint32_t SWAP(uint32_t a) {
+#ifdef WORDS_BIGENDIAN
+    return ( (a<<24&0xff000000) | (a<< 8&0x00ff0000) |
+	     (a>> 8&0x0000ff00) | (a>>24&0x000000ff)); 
+#else
+    return a;
+#endif
+} 
+
+static inline int avi_stream_id(unsigned int id){
+  unsigned char *p=(unsigned char *)&id;
+  unsigned char a,b;
+#if WORDS_BIGENDIAN
+  a=p[3]-'0'; b=p[2]-'0';
+#else
+  a=p[0]-'0'; b=p[1]-'0';
+#endif
+  if(a>9 || b>9) return 100; // invalid ID
+  return a*10+b;
+}
+
+// returns 1 for video
+//         2 for 1st audio
+//         3 for 2nd audio
+static int avi_stream_nr(int id)
+{
+    unsigned char *p = (unsigned char *)&id;
+
+#if WORDS_BIGENDIAN
+    if (p[1] == 'd') {
+	return 1;
+    } else  {
+	int res = (p[3]-'0')+(p[2]-'0');
+	res = (res==0)?2:res+1;
+	return res;
+    }
+#else
+    if (p[2] == 'd') {
+	return 1;
+    } else {
+	int res = (p[0]-'0')+(p[1]-'0');
+	res = (res==0)?2:res+1;
+	return res;
+    }
+#endif
+    return 0;
+}
+
 const int LEN=10;
 
+typedef enum {
+    UNKNOWN = 0,
+    RIFF,
+    AVIIDX1,
+    MPIDX1,
+} ftype_t;
 
-int AVI_read_data_fast(avi_t *AVI, char *buf, off_t *pos, off_t *len, off_t *key)
+typedef struct {
+    uint32_t ckid;
+    uint32_t dwFlags;
+    uint32_t dwChunkOffset;
+    uint32_t dwChunkLength;
+} AVIINDEXENTRY;
+
+int aviidx1_to_mpidx1(char *in_file, FILE *out_fd)
+{
+    char *data;
+    FILE *in;
+    int size=0, i;
+    AVIINDEXENTRY *idx;
+    char line[255], d;
+
+    in = fopen (in_file, "r");
+    if (!in) return 1;
+
+    // skip header
+    fgets (line, 255, in);
+    fgets (line, 255, in);
+    while (fgets(line, 255, in)) {
+	d = line[5] - '1';
+	if        (d == 0) {
+	    size++;
+	} else if (d == 1 || d == 2 || d == 3 || d == 4 ||
+		   d == 5 || d == 6 || d == 7 || d == 8  ) {
+	    size++;
+	} else continue;
+    }
+    data = malloc (size * sizeof (AVIINDEXENTRY));
+    fseek(in, 0, SEEK_SET);
+    fgets (line, 255, in); fgets (line, 255, in);
+
+    i = size;
+    idx = &((AVIINDEXENTRY *)data)[0];
+    while (fgets(line, 255, in) && i--) {
+	char *c=line;
+	idx->ckid=*(int *)c;
+	idx->ckid=SWAP(idx->ckid);
+	c = strchr(c, ' ')+1; // type
+	c = strchr(c, ' ')+1; // chunk
+	c = strchr(c, ' ')+1; // chunk/type
+	c = strchr(c, ' ')+1; // pos
+	idx->dwChunkOffset = strtol(c, &c, 10);
+	idx->dwChunkLength = strtol(c+1, &c, 10);
+	idx->dwFlags = strtol(c+1, &c, 10);
+	idx->dwFlags = idx->dwFlags?0x10:0;
+	idx++;
+
+    }
+    fwrite ("MPIDX1", 6, 1, out_fd);
+    fwrite (&size, 4, 1, out_fd);
+    fwrite (data, sizeof(AVIINDEXENTRY), size, out_fd);
+
+    free(data);
+    fclose (in);
+    fclose(out_fd);
+    return 0;
+}
+int mpidx1_to_aviidx1(char *in_file, FILE *out_fd)
+{
+    char head[10];
+    char *data;
+    FILE *in;
+    int size, i;
+    AVIINDEXENTRY *idx;
+    int streams[100];
+
+    in = fopen (in_file, "r");
+    if (!in) return 1;
+    fread (head, 10, 1, in);
+
+    // header. Magic tag is AVIIDX1
+    fprintf(out_fd, "AVIIDX1 # Generated by %s (%s-%s)\n", EXE, PACKAGE, VERSION); // Magic
+    fprintf(out_fd, "TAG TYPE CHUNK CHUNK/TYPE POS LEN KEY MS\n");
+
+    size = *(int *)(head+6);
+    data = malloc (size * sizeof(AVIINDEXENTRY));
+    memset (streams, 0, sizeof(streams));
+    if (size != fread (data, sizeof(AVIINDEXENTRY), size, in)) {
+	perror("fread"); return 1;
+    }
+    for (i = 0; i<size; i++) {
+	uint32_t ckid;
+	idx = &((AVIINDEXENTRY *)data)[i];
+	ckid = SWAP(idx->ckid);
+	fprintf(out_fd, 
+		"%.4s %d %d %d %d %d %d 0\n", 
+		(char *)&ckid, 
+		avi_stream_nr(idx->ckid),
+		i, 
+		streams[avi_stream_id(idx->ckid)],
+		idx->dwChunkOffset, 
+		idx->dwChunkLength, 
+		idx->dwFlags?1:0);
+
+	streams[avi_stream_id(idx->ckid)]++;
+    }
+
+    
+    free(data);
+    fclose (in);
+    fclose(out_fd);
+    
+    return 0;
+}
+
+// data is only 8 bytes long
+int AVI_read_data_fast(avi_t *AVI, char *buf, off_t *pos, off_t *len, off_t *key, char *data)
 {
 
 /*
@@ -77,10 +248,10 @@ int AVI_read_data_fast(avi_t *AVI, char *buf, off_t *pos, off_t *len, off_t *key
  *    3 = audio data read from track 1
  *    4 = audio data read from track 2
  *    ....
+ *   10 = traditional idx1 chunk
  */
 
    off_t n;
-   char data[8];
    int rlen;
    *key=(off_t)0;
 
@@ -90,121 +261,131 @@ int AVI_read_data_fast(avi_t *AVI, char *buf, off_t *pos, off_t *len, off_t *key
    {
       /* Read tag and length */
 
-      if( read(AVI->fdes,data,8) != 8 ) return 0;
+      if( xio_read(AVI->fdes,data,8) != 8 ) return 0;
 
       n = PAD_EVEN(str2ulong(data+4));
 
+      if(strncasecmp(data,"LIST",4) == 0) {
+	  continue;
+      }
+
+      if(strncasecmp(data,"movi",4) == 0 ||
+         strncasecmp(data,"rec ",4) == 0) {
+	  xio_lseek(AVI->fdes,-4,SEEK_CUR);
+	  continue;
+      }
+
       if(strncasecmp(data,"IDX1",4) == 0)
       {
 	 // deal with it to extract keyframe info
          *len = str2ulong(data+4);
-	 *pos = lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
+	 *pos = xio_lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
 	 //fprintf (stderr, "Found an index chunk at %lld len %lld\n", *pos, *len);
-         if(lseek(AVI->fdes,n,SEEK_CUR)==(off_t)-1)  return 0;
+         if(xio_lseek(AVI->fdes,n,SEEK_CUR)==(off_t)-1)  return 0;
 	 return 10;
       }
 
       if(strncasecmp(data,AVI->video_tag,3) == 0)
       {
          *len = str2ulong(data+4);
-	 *pos = lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
+	 *pos = xio_lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
          AVI->video_pos++;
-	 rlen = (n<LEN)?n:LEN;
-	 read(AVI->fdes, buf, rlen);
-         if(lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
+	 rlen = n;
+	 xio_read(AVI->fdes, buf, rlen);
+         if(xio_lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
          return 1;
       }
       else if(AVI->anum>=1 && strncasecmp(data,AVI->track[0].audio_tag,4) == 0)
       {
          *len = str2ulong(data+4);
-	 *pos = lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
+	 *pos = xio_lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
 	 AVI->track[0].audio_posc++;
 	 rlen = (n<LEN)?n:LEN;
-	 read(AVI->fdes, buf, rlen);
-         if(lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
+	 xio_read(AVI->fdes, buf, rlen);
+         if(xio_lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
          return 2;
          break;
       }
       else if(AVI->anum>=2 && strncasecmp(data,AVI->track[1].audio_tag,4) == 0)
       {
          *len = str2ulong(data+4);
-	 *pos = lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
+	 *pos = xio_lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
 	 AVI->track[1].audio_posc++;
 	 rlen = (n<LEN)?n:LEN;
-	 read(AVI->fdes, buf, rlen);
-         if(lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
+	 xio_read(AVI->fdes, buf, rlen);
+         if(xio_lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
          return 3;
          break;
       }
       else if(AVI->anum>=3 && strncasecmp(data,AVI->track[2].audio_tag,4) == 0)
       {
          *len = str2ulong(data+4);
-	 *pos = lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
+	 *pos = xio_lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
 	 AVI->track[2].audio_posc++;
 	 rlen = (n<LEN)?n:LEN;
-	 read(AVI->fdes, buf, rlen);
-         if(lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
+	 xio_read(AVI->fdes, buf, rlen);
+         if(xio_lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
          return 4;
          break;
       }
       else if(AVI->anum>=4 && strncasecmp(data,AVI->track[3].audio_tag,4) == 0)
       {
          *len = str2ulong(data+4);
-	 *pos = lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
+	 *pos = xio_lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
 	 AVI->track[3].audio_posc++;
 	 rlen = (n<LEN)?n:LEN;
-	 read(AVI->fdes, buf, rlen);
-         if(lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
+	 xio_read(AVI->fdes, buf, rlen);
+         if(xio_lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
          return 5;
          break;
       }
       else if(AVI->anum>=5 && strncasecmp(data,AVI->track[4].audio_tag,4) == 0)
       {
          *len = str2ulong(data+4);
-	 *pos = lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
+	 *pos = xio_lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
 	 AVI->track[4].audio_posc++;
 	 rlen = (n<LEN)?n:LEN;
-	 read(AVI->fdes, buf, rlen);
-         if(lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
+	 xio_read(AVI->fdes, buf, rlen);
+         if(xio_lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
          return 6;
          break;
       }
       else if(AVI->anum>=6 && strncasecmp(data,AVI->track[5].audio_tag,4) == 0)
       {
          *len = str2ulong(data+4);
-	 *pos = lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
+	 *pos = xio_lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
 	 AVI->track[5].audio_posc++;
 	 rlen = (n<LEN)?n:LEN;
-	 read(AVI->fdes, buf, rlen);
-         if(lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
+	 xio_read(AVI->fdes, buf, rlen);
+         if(xio_lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
          return 7;
          break;
       }
       else if(AVI->anum>=7 && strncasecmp(data,AVI->track[6].audio_tag,4) == 0)
       {
          *len = str2ulong(data+4);
-	 *pos = lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
+	 *pos = xio_lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
 	 AVI->track[6].audio_posc++;
 	 rlen = (n<LEN)?n:LEN;
-	 read(AVI->fdes, buf, rlen);
-         if(lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
+	 xio_read(AVI->fdes, buf, rlen);
+         if(xio_lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
          return 8;
          break;
       }
       else if(AVI->anum>=8 && strncasecmp(data,AVI->track[7].audio_tag,4) == 0)
       {
          *len = str2ulong(data+4);
-	 *pos = lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
+	 *pos = xio_lseek(AVI->fdes, 0, SEEK_CUR)-(off_t)8;
 	 AVI->track[7].audio_posc++;
 	 rlen = (n<LEN)?n:LEN;
-	 read(AVI->fdes, buf, rlen);
-         if(lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
+	 xio_read(AVI->fdes, buf, rlen);
+         if(xio_lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
          return 9;
          break;
       } else {
-	  lseek(AVI->fdes,-4,SEEK_CUR);
+	  if(xio_lseek(AVI->fdes,n,SEEK_CUR)==(off_t)-1)  return 0;
       }
-      // else if(lseek(AVI->fdes,n,SEEK_CUR)==(off_t)-1)  return 0;
+      // else if(xio_lseek(AVI->fdes,n,SEEK_CUR)==(off_t)-1)  return 0;
    }
 }
 
@@ -224,15 +405,11 @@ int is_key(unsigned char *data, long size, char *codec)
 
         for(i = 0; i < size - 5; i++)
         {
-                if( data[i]     == 0x00 && 
-                        data[i + 1] == 0x00 &&
-                        data[i + 2] == 0x01 &&
-                        data[i + 3] == 0xb6)
-                {
-                        if((data[i + 4] & 0xc0) == 0x0) 
-                                return 1;
-                        else
-                                return 0;
+                if( data[i]     == 0x00 && data[i + 1] == 0x00 &&
+		    data[i + 2] == 0x01 && data[i + 3] == 0xb6) {
+
+                        if((data[i + 4] & 0xc0) == 0x0) return 1;
+                        else                            return 0;
                 }
         }
         
@@ -270,18 +447,25 @@ int main(int argc, char *argv[])
   int aud_bitrate = 0;
 
   FILE *out_fd    = NULL;
-  int open_without_index=0;
+  int open_without_index=0,index_keyframes=0;
+  int force_with_index=0;
 
   double vid_ms = 0.0, print_ms = 0.0;
   double aud_ms [ AVI_MAX_TRACKS ];
   char tag[8];
-  char data[100];
+  char *data;
   int vid_chunks=0, aud_chunks[AVI_MAX_TRACKS];
   off_t pos, len, key, index_pos=0, index_len=0,size=0;
   struct stat st;
   char *codec;
   int idx_type=0;
   off_t ioff;
+  char fcclen[8]; // FOURCC + len
+
+  ftype_t ftype;
+  FILE *idxfile;
+
+  tc_memcpy_init(0, -1);
 
   if(argc==1) usage(EXIT_FAILURE);
 
@@ -290,7 +474,7 @@ int main(int argc, char *argv[])
     aud_ms[i] = 0;
   }
 
-  while ((ch = getopt(argc, argv, "a:vi:o:n?h")) != -1)
+  while ((ch = getopt(argc, argv, "a:vi:o:nf?h")) != -1)
     {
 
 	switch (ch) {
@@ -323,6 +507,17 @@ int main(int argc, char *argv[])
 	    open_without_index=1;
 	
 	    break;
+
+	case 'x':
+
+	    open_without_index=1;
+	    index_keyframes=1;
+	
+	    break;
+
+	case 'f':
+	    force_with_index=1;
+	    break;
 	
 	case 'v':
 	    version();
@@ -345,6 +540,25 @@ int main(int argc, char *argv[])
       exit(1);
   }
 
+  idxfile = fopen(in_file, "r");
+  fread (fcclen, 8, 1, idxfile);
+  if      (strncasecmp(fcclen, "RIFF", 4)    == 0) ftype = RIFF;
+  else if (strncasecmp(fcclen, "AVIIDX1", 7) == 0) ftype = AVIIDX1;
+  else if (strncasecmp(fcclen, "MPIDX1", 6)  == 0) ftype = MPIDX1;
+  else    ftype = UNKNOWN;
+
+  fclose (idxfile);
+
+  switch (ftype) {
+      case RIFF:    fprintf(stderr, "[%s] Seems to be an AVI file.\n", EXE); break;
+      case AVIIDX1: fprintf(stderr, "[%s] Converting a transcode to an mplayer index file.\n", EXE); 
+		    return aviidx1_to_mpidx1(in_file, out_fd);
+      case MPIDX1:  fprintf(stderr, "[%s] Converting an mplayer to a transcode index file.\n", EXE); 
+		    return mpidx1_to_aviidx1(in_file, out_fd);
+      default:      fprintf(stderr, "[%s] Unrecognized format\n", EXE); return (1);
+  }
+
+
   // if file is larger than 2GB, regen index
 
   if (stat(in_file, &st)<0) {
@@ -354,10 +568,11 @@ int main(int argc, char *argv[])
 
   size = st.st_size;
   if (size > (off_t)AVI_MAX_LEN/2)
-      open_without_index = 1;
+      if (!force_with_index) open_without_index = 1;
 
   if (open_without_index) 
-      fprintf(stderr, "[%s] Open \"%s\" without index\n",EXE, in_file);
+      if (index_keyframes) fprintf(stderr, "[%s] Open \"%s\" without index and don't use index for keyframes info\n",EXE, in_file);
+      else fprintf(stderr, "[%s] Open \"%s\" without index but use index (if any) for keyframes info\n",EXE, in_file);
   else
       fprintf(stderr, "[%s] Open \"%s\" with index (fast)\n", EXE, in_file);
 
@@ -365,6 +580,8 @@ int main(int argc, char *argv[])
   fprintf(out_fd, "AVIIDX1 # Generated by %s (%s-%s)\n", EXE, PACKAGE, VERSION); // Magic
   fprintf(out_fd, "TAG TYPE CHUNK CHUNK/TYPE POS LEN KEY MS\n");
 
+  data = malloc (5*1024*1204);
+
   if (open_without_index) {
 
     // open file with index.
@@ -384,7 +601,7 @@ int main(int argc, char *argv[])
     pos = key = len = (off_t)0;
     i = 0;
 
-    while ( (ret = AVI_read_data_fast (avifile1, data, &pos, &len, &key)) != 0) {
+    while ( (ret = AVI_read_data_fast (avifile1, data, &pos, &len, &key, fcclen)) != 0) {
       int audtr = ret-2;
 
       /* don't need this and it saves time
@@ -408,16 +625,16 @@ int main(int argc, char *argv[])
       }
 
       switch (ret) {
-	case 1: sprintf(tag, "00db");
+	case 1: tc_memcpy(tag, fcclen, 4);
 		print_ms = vid_ms = (avifile1->video_pos)*1000.0/fps;
 		chunk = avifile1->video_pos;
-		key = is_key(data, LEN, codec);
+		key = is_key(data, len, codec);
 		break;
 	case 2: case 3:
 	case 4: case 5:
 	case 6: case 7:
 	case 8:
-	case 9: sprintf(tag, "0%dwb", audtr+1);
+	case 9: tc_memcpy(tag, fcclen, 4);
 		print_ms = aud_ms[audtr];
 		chunk = avifile1->track[audtr].audio_posc;
 		break;
@@ -437,7 +654,7 @@ int main(int argc, char *argv[])
 
       //if (index_pos != pos)
       // tag, chunk_nr
-      fprintf(out_fd, "%s %d %ld %ld %lld %lld %lld %.2f\n", tag, ret, i, chunk-1, pos, len, key, print_ms);
+      fprintf(out_fd, "%.4s %d %ld %ld %lld %lld %lld %.2f\n", tag, ret, i, chunk-1, pos, len, key, print_ms);
       i++;
 
       // don't update the counter every chunk
@@ -451,8 +668,8 @@ int main(int argc, char *argv[])
     fprintf(stderr, "\n");
 
     // check if we have found an index chunk to restore keyframe info
-    if (!index_pos || !index_len)
-	goto out;
+    if (!index_pos || !index_len || index_keyframes)
+	goto aviout;
 
     fprintf(stderr, "[%s] Found an index chunk. Using it to regenerate keyframe info.\n", EXE);
     fseek (out_fd, 0, SEEK_SET);
@@ -463,9 +680,9 @@ int main(int argc, char *argv[])
     len = (off_t)0;
     vid_chunks = 0;
 
-    lseek(avifile1->fdes, index_pos+8, SEEK_SET);
+    xio_lseek(avifile1->fdes, index_pos+8, SEEK_SET);
     while (len<index_len) {
-	read(avifile1->fdes, tag, 8);
+	xio_read(avifile1->fdes, tag, 8);
 	
 	// if its a keyframe and is a video chunk
 	if (str2ulong(tag+4) && tag[1] == '0') {
@@ -496,7 +713,7 @@ int main(int argc, char *argv[])
 		      tagn, typen, chunkn, chunkptypen, posn, lenn, 1, msn);
 	}
 
-	lseek(avifile1->fdes, 8, SEEK_CUR);
+	xio_lseek(avifile1->fdes, 8, SEEK_CUR);
 	len += 16;
     }
     
@@ -511,6 +728,8 @@ int main(int argc, char *argv[])
     }
     i=0;
 
+    AVI_info(avifile1);
+
     if(avifile1->idx)
     {
       off_t pos, len;
@@ -524,16 +743,16 @@ int main(int argc, char *argv[])
       pos = str2ulong(avifile1->idx[i]+ 8);
       len = str2ulong(avifile1->idx[i]+12);
 
-      lseek(avifile1->fdes,pos,SEEK_SET);
-      if(read(avifile1->fdes,data,8)!=8) return 1;
+      xio_lseek(avifile1->fdes,pos,SEEK_SET);
+      if(xio_read(avifile1->fdes,data,8)!=8) return 1;
       if( strncasecmp(data,avifile1->idx[i],4)==0 && str2ulong(data+4)==len )
       {
          idx_type = 1; /* Index from start of file */
       }
       else
       {
-         lseek(avifile1->fdes,pos+avifile1->movi_start-4,SEEK_SET);
-         if(read(avifile1->fdes,data,8)!=8) return 1;
+         xio_lseek(avifile1->fdes,pos+avifile1->movi_start-4,SEEK_SET);
+         if(xio_read(avifile1->fdes,data,8)!=8) return 1;
          if( strncasecmp(data,avifile1->idx[i],4)==0 && str2ulong(data+4)==len )
          {
             idx_type = 2; /* Index from start of movi list */
@@ -546,8 +765,9 @@ int main(int argc, char *argv[])
    //fprintf(stderr, "index type (%d), ioff (%ld)\n", idx_type, (long)ioff);
     i=0;
 
+    //printf("nr idx: %d\n", avifile1->n_idx);
     while (i<avifile1->n_idx) {
-      memcpy(tag, avifile1->idx[i], 4);
+      tc_memcpy(tag, avifile1->idx[i], 4);
       // tag
       fprintf(out_fd, "%c%c%c%c", 
 	  avifile1->idx[i][0], avifile1->idx[i][1],
@@ -597,8 +817,9 @@ int main(int argc, char *argv[])
   }
 
 
-out:
-  if (out_fd) fclose (out_fd);
+aviout:
+  free(data);
+  if (out_fd!=stdout) fclose (out_fd);
   AVI_close(avifile1);
 
   return(0);
